module Nri.Ui.AssignmentIcon.V2 exposing
    ( diagnostic, planningDiagnosticCircled, unitDiagnosticCircled
    , practice, practiceCircled
    , quiz, quizCircled, passageQuizCircled
    , quickWrite, guidedDraft, peerReview, selfReview, dailyWriting, novels
    , quickWriteCircled, guidedDraftCircled, peerReviewCircled, selfReviewCircled, dailyWritingCircled, novelsCircled, gradingAssistantCircled
    , submitting, rating, revising
    , startPrimary, startSecondary
    , assessment, standards, writing, modules
    )

{-|


### Patch changes

  - change circular path elements to circle elements using encircle helper


# Quiz Engine

@docs diagnostic, planningDiagnosticCircled, unitDiagnosticCircled
@docs practice, practiceCircled
@docs quiz, quizCircled, passageQuizCircled


# Writing

@docs quickWrite, guidedDraft, peerReview, selfReview, dailyWriting, novels
@docs quickWriteCircled, guidedDraftCircled, peerReviewCircled, selfReviewCircled, dailyWritingCircled, novelsCircled, gradingAssistantCircled


# Stages

@docs submitting, rating, revising


# Start

@docs startPrimary, startSecondary


# Activities

@docs assessment, standards, writing, modules


# Example usage

    import Html.Styled exposing (Html)
    import Nri.Ui.AssignmentIcon.V2 as AssignmentIcon
    import Nri.Ui.Colors.V1 as Colors
    import Nri.Ui.Svg.V1 as Svg

    view : Html msg
    view =
        AssignmentIcon.diagnostic
            |> Svg.withColor Colors.lichen
            |> Svg.toHtml

-}

import Nri.Ui.Svg.V1
import Svg.Styled as Svg exposing (Svg)
import Svg.Styled.Attributes as Attributes


encircle : Float -> (Svg Never -> List (Svg Never)) -> Nri.Ui.Svg.V1.Svg
encircle diameter circleToIcon =
    let
        diameterStr =
            String.fromFloat diameter

        radius =
            diameter / 2

        radiusStr =
            String.fromFloat radius
    in
    Svg.circle
        [ Attributes.cx radiusStr
        , Attributes.cy radiusStr
        , Attributes.r radiusStr
        ]
        []
        |> circleToIcon
        |> Nri.Ui.Svg.V1.init
            ("0 0 "
                ++ diameterStr
                ++ " "
                ++ diameterStr
            )


{-| -}
diagnostic : Nri.Ui.Svg.V1.Svg
diagnostic =
    Nri.Ui.Svg.V1.init "0 0 43.8 41"
        [ Svg.path [ Attributes.d "M32.5,41c-1.1,0-2.1-0.4-2.9-1.1c-1.6-1.5-1.6-3.9-0.2-5.5c0,0,0,0,0,0l0.2-0.2c0.2-0.2,0.3-0.4,0.5-0.6H12.4l-0.1-0.1l0,0 l-0.1-0.1l0,0l-0.1-0.1l0,0L12,33l0,0c0,0,0-0.1,0-0.1l0,0c0,0,0-0.1,0-0.1v-0.1l0,0c0.1-0.9,0.5-1.8,1.2-2.4c0.9-0.8,1-2.2,0.1-3.1 c0,0-0.1-0.1-0.1-0.1c-1-0.9-2.6-0.9-3.6,0c-0.9,0.8-1,2.2-0.1,3.1l0.1,0.2c0.7,0.6,1.1,1.5,1.2,2.4c0.1,0.4-0.1,0.9-0.6,1 c0,0,0,0,0,0H10H0.8c-0.4,0-0.8-0.4-0.8-0.8v-11l0,0c0,0,0,0,0-0.1v-0.4l0.1-0.1h0.1h0.7c0.9,0.1,1.8,0.5,2.4,1.2 c0.4,0.5,1,0.7,1.6,0.7c0.6,0,1.2-0.3,1.6-0.7c0.9-1,0.9-2.6,0-3.7c-0.8-0.9-2.1-1-3-0.2c-0.1,0.1-0.1,0.1-0.2,0.2 c-0.6,0.7-1.5,1.2-2.5,1.2H0.2L0.1,20l0,0l-0.1-0.1l0,0L0,19.9l0,0v-0.1l0,0c0,0,0-0.1,0-0.1l0,0V8.2c0-0.4,0.4-0.8,0.8-0.8h8.1 C8.8,7.2,8.6,7,8.5,6.8C6.9,5.3,6.8,2.9,8.3,1.3l0.2-0.2c1.6-1.5,4.2-1.5,5.8,0c1.6,1.4,1.6,3.9,0.2,5.4l-0.2,0.2 c-0.2,0.2-0.3,0.4-0.5,0.6h17.7h0.1l0,0l0.1,0.1l0,0c0.2,0.2,0.2,0.4,0.2,0.7c-0.1,0.9-0.5,1.8-1.2,2.4c-0.9,0.9-1,2.3-0.1,3.3 c0,0,0.1,0.1,0.1,0.1c1,0.9,2.6,0.9,3.6,0c0.9-0.8,1-2.2,0.2-3.1l-0.2-0.1C33.5,10,33.1,9.2,33,8.3c0-0.1,0-0.2,0-0.2 c0-0.4,0.4-0.8,0.8-0.8H43c0.4,0,0.8,0.4,0.8,0.8v11c0,0,0,0.1,0,0.1l0,0v0.1l0,0v0.1l0,0l-0.1,0.1l0,0l-0.1,0.1l0,0l-0.1,0.1H43 c-0.9-0.1-1.8-0.5-2.4-1.2c-0.4-0.5-1-0.7-1.6-0.7c-0.6,0-1.2,0.3-1.6,0.7c-0.9,1-0.9,2.6,0,3.7c0.8,0.9,2.1,1,3,0.2 c0.1-0.1,0.2-0.1,0.2-0.2c0.6-0.6,1.5-1,2.4-1.1l0,0c0.4,0,0.8,0.3,0.8,0.8c0,0,0,0.1,0,0.1c0,0,0,0.1,0,0.1v10.9 c0,0.4-0.4,0.8-0.8,0.8h-8.1c0.1,0.2,0.3,0.4,0.4,0.6c1.6,1.4,1.6,3.9,0.2,5.4l-0.2,0.2C34.6,40.6,33.5,41,32.5,41z M31.9,33 c-0.1,0.9-0.5,1.8-1.2,2.4c-0.9,0.8-1,2.2-0.2,3.1l0.2,0.2c1,0.9,2.6,0.9,3.6,0c0.9-0.8,1-2.2,0.2-3.1l-0.2-0.2 c-0.7-0.6-1.1-1.5-1.2-2.4c0-0.1,0-0.1,0-0.2c0-0.2,0.1-0.4,0.2-0.5l0,0l0.1-0.1l0,0l0.1-0.1h8.7V23c-0.2,0.1-0.4,0.3-0.6,0.5 c-1.3,1.5-3.7,1.7-5.2,0.3c-0.1-0.1-0.2-0.2-0.3-0.3c-1.5-1.7-1.5-4.2,0-5.9c1.4-1.5,3.7-1.7,5.2-0.3c0.1,0.1,0.2,0.2,0.3,0.3 c0.2,0.2,0.4,0.3,0.6,0.5V9h-7.3c0.1,0.3,0.3,0.6,0.5,0.8c1.6,1.4,1.6,3.9,0.2,5.4l-0.2,0.2c-1.6,1.5-4.2,1.5-5.8,0 C28,14,27.9,11.5,29.4,10l0.2-0.2C29.8,9.6,29.9,9.3,30,9h-7.3v8.8c0.2-0.1,0.4-0.3,0.6-0.5c1.4-1.5,3.7-1.7,5.2-0.3 c0.1,0.1,0.2,0.2,0.3,0.3c1.5,1.7,1.5,4.2,0,5.9c-0.7,0.8-1.7,1.2-2.8,1.2c-1.1,0-2.1-0.5-2.8-1.2c-0.2-0.2-0.4-0.3-0.6-0.5V32h8.4 c0.1,0,0.3,0.1,0.4,0.1l0,0l0.1,0.1l0,0v0.1v0.1l0,0c0.1,0.1,0.1,0.3,0.1,0.4C31.7,32.8,31.8,32.9,31.9,33L31.9,33z M21.1,32V21.7 l0,0c0-0.4,0.3-0.8,0.7-0.8c0,0,0,0,0,0H22c1,0.1,1.8,0.5,2.5,1.2c0.4,0.5,1,0.7,1.6,0.7c0.6,0,1.2-0.3,1.6-0.7c0.9-1,0.9-2.6,0-3.7 c-0.8-0.9-2.1-1-3-0.2c-0.1,0.1-0.1,0.1-0.2,0.2c-0.6,0.7-1.5,1.2-2.5,1.2h-0.1c-0.4,0-0.8-0.3-0.8-0.8c0,0,0-0.1,0-0.1l0,0V9h-8.4 c-0.4,0-0.8-0.4-0.8-0.8l0,0c0.1-1,0.5-1.9,1.2-2.5c0.9-0.8,1-2.2,0.1-3.1l-0.1-0.1c-1-0.9-2.6-0.9-3.6,0c-0.9,0.8-1,2.2-0.1,3.1 l0.1,0.1c0.7,0.6,1.1,1.4,1.2,2.3c0,0.1,0,0.1,0,0.2C10.8,8.6,10.4,9,10,9H1.6v9c0.2-0.1,0.4-0.3,0.6-0.5c1.4-1.5,3.7-1.7,5.2-0.3 c0.1,0.1,0.2,0.2,0.3,0.3c1.5,1.7,1.5,4.2,0,5.9C7,24.2,6,24.7,5,24.7c-1.1,0-2.1-0.5-2.8-1.2c-0.2-0.2-0.4-0.3-0.6-0.5v9H9 c-0.1-0.2-0.3-0.4-0.5-0.6c-1.6-1.4-1.6-3.9-0.2-5.4l0.2-0.2c1.6-1.5,4.2-1.5,5.8,0c1.6,1.4,1.6,3.9,0.2,5.4l-0.2,0.2 c-0.2,0.2-0.3,0.4-0.5,0.6L21.1,32z" ] [] ]


{-| -}
peerReview : Nri.Ui.Svg.V1.Svg
peerReview =
    Nri.Ui.Svg.V1.init "0 0 57 58"
        [ Svg.g
            [ Attributes.fill "currentcolor"
            , Attributes.fillRule "evenodd"
            ]
            [ Svg.path [ Attributes.d "M16.441 43.288v-10.59l.002-.095v-3.781l-1.263 2.46c-.373.728-1.244 1.029-1.945.668-.7-.36-.966-1.243-.593-1.97l2.476-4.826c.044-.083.092-.162.147-.232a1.648 1.648 0 0 1 1.558-1.11h4.399l-2.218 4.32c-.723 1.414-.238 3.208 1.228 3.963.919.47 1.944.392 2.758-.08l.056-.036v11.309H20.16v-9.093h-.751v9.093h-2.968zm.45-23.648a2.95 2.95 0 1 1 5.903 0 2.953 2.953 0 0 1-2.952 2.952 2.952 2.952 0 0 1-2.95-2.952z" ] []
            , Svg.path [ Attributes.d "M24.376 43.288v-11.55c0-.035 0-.07.002-.108V27.464l-1.392 2.71c-.412.805-1.373 1.135-2.146.739-.774-.396-1.064-1.371-.653-2.174l2.729-5.319c.047-.091.102-.176.162-.255a1.818 1.818 0 0 1 1.716-1.224h6.54c.796 0 1.472.512 1.717 1.224.06.079.114.164.161.255l2.73 5.32c.412.802.12 1.777-.654 2.173-.773.396-1.734.066-2.144-.739l-1.392-2.708v4.104c0 .054-.002.106-.008.158v11.56h-3.291v-9.901h-.786v9.9h-3.291zm3.744-29.2h.006a3.255 3.255 0 0 1 3.251 3.253 3.255 3.255 0 0 1-3.254 3.254 3.255 3.255 0 0 1-3.254-3.254 3.255 3.255 0 0 1 3.251-3.253z" ] []
            , Svg.path [ Attributes.d "M33.073 43.288V31.972l.065.044c.815.47 1.84.55 2.758.079 1.468-.755 1.951-2.549 1.228-3.963l-2.217-4.32h4.398c.722 0 1.336.464 1.558 1.11.053.072.103.149.147.232l2.476 4.825c.373.728.108 1.612-.593 1.97-.7.362-1.572.06-1.947-.667l-1.261-2.46v3.725c0 .048-.002.095-.007.143V43.288h-2.967v-9.093h-.75v9.093h-2.888zm.37-23.648a2.951 2.951 0 1 1 5.902 0 2.953 2.953 0 0 1-2.951 2.952 2.953 2.953 0 0 1-2.952-2.952zM52.869 45.376c.773-.062 1.091.482 1.13.966.038.483-.191 1.072-.965 1.133l-4.29.343c-.01 0-.02-.005-.032-.004-.017.005-.035.012-.052.013-.483.038-1.07-.192-1.13-.968l-.342-4.303a1.053 1.053 0 0 1 .962-1.133 1.052 1.052 0 0 1 1.13.966l.155 1.953c6.516-8.931 6.1-23.482-1.259-31.686-.599-.663-.442-1.286-.099-1.634.336-.344.997-.505 1.661.226 8.007 8.926 8.49 24.528 1.453 34.262l1.678-.134zm-6.36-37.96c.004.018.011.035.012.053.039.484-.19 1.068-.966 1.13l-4.305.343a1.054 1.054 0 0 1-1.132-.963 1.051 1.051 0 0 1 .964-1.13l1.955-.155C34.105.178 19.554.593 11.35 7.954c-.662.6-1.285.441-1.633.097-.345-.335-.506-.994.227-1.66 8.925-8.008 24.527-8.489 34.26-1.452l-.133-1.678c-.062-.774.481-1.092.965-1.13.485-.04 1.072.19 1.133.963l.344 4.292c0 .01-.004.02-.004.03zm-.573 42.24c.343.34.503 1.001-.227 1.668-8.898 8.032-24.453 8.514-34.157 1.457l.133 1.683c.062.775-.479 1.094-.961 1.134-.483.038-1.068-.192-1.13-.967l-.342-4.304c-.001-.012.004-.022.003-.033-.002-.017-.011-.035-.012-.052-.039-.485.192-1.072.963-1.133l4.292-.343a1.052 1.052 0 0 1 .168 2.098l-1.932.154c8.905 6.53 23.398 6.119 31.573-1.26.66-.602 1.282-.445 1.63-.101zM6.848 15.622l-.154-1.954C.178 22.598.594 37.15 7.953 45.352c.6.663.442 1.288.099 1.634-.335.345-.996.506-1.66-.227-8.008-8.925-8.49-24.526-1.453-34.26l-1.679.134c-.772.062-1.091-.482-1.13-.966-.038-.485.19-1.071.964-1.133l4.292-.343c.01-.001.02.003.03.003.019 0 .036-.01.054-.012.483-.037 1.068.192 1.13.966l.342 4.306a1.052 1.052 0 0 1-.964 1.131 1.052 1.052 0 0 1-1.13-.964z" ] []
            ]
        ]


{-| -}
practice : Nri.Ui.Svg.V1.Svg
practice =
    Nri.Ui.Svg.V1.init "0 0 42.1 42"
        [ Svg.path [ Attributes.d "M36.1,9.5l-1.9-0.3l2.9-2.9L39,6.6L36.1,9.5z M20.5,40c-3.7,0-7.2-1.1-10.3-3.1c-0.3-0.2-0.6-0.2-0.9-0.1l-6.7,2.5l2.5-6.7 c0.1-0.3,0.1-0.6-0.1-0.9c-5.7-8.5-3.4-20,5.1-25.6c6-4,13.7-4.2,19.9-0.5L26.7,9c-6.9-3.4-15.3-0.6-18.8,6.3s-0.6,15.3,6.3,18.8 c6.9,3.4,15.3,0.6,18.8-6.3c2-3.9,2-8.6,0-12.5l3.3-3.3c5.3,8.7,2.5,20.1-6.2,25.4C27.2,39.1,23.9,40,20.5,40z M31.5,14l-1.9-0.3 l2.9-2.9l1.9,0.3L31.5,14z M31.1,9.5l-2.9,2.9L28,10.5l2.9-2.9L31.1,9.5z M26.1,21.5c0,3.1-2.5,5.5-5.5,5.5c-3.1,0-5.5-2.5-5.5-5.5 c0-3.1,2.5-5.5,5.5-5.5c1.1,0,2.2,0.3,3.2,1l-3.4,3.4c-0.6,0.2-1,0.8-0.8,1.4c0.2,0.6,0.8,1,1.4,0.8c0.4-0.1,0.7-0.4,0.8-0.8 l3.4-3.4C25.7,19.3,26,20.4,26.1,21.5z M26.1,10.9l0.5,3.2l-1.5,1.5c-3.3-2.5-8-1.9-10.5,1.4c-2.5,3.3-1.9,8,1.4,10.5 s8,1.9,10.5-1.4c2.1-2.7,2.1-6.4,0-9.1l1.5-1.5l3.2,0.5c3.1,5.9,0.8,13.1-5,16.2c-5.9,3.1-13.1,0.8-16.2-5s-0.8-13.1,5-16.2 C18.4,9.1,22.6,9.1,26.1,10.9z M35.5,3l0.3,1.9l-2.9,2.9l-0.3-1.9L35.5,3z M42,5.5c-0.1-0.3-0.4-0.6-0.8-0.7l-3.5-0.5l-0.5-3.6 C37,0.3,36.5-0.1,36,0c-0.2,0-0.4,0.1-0.5,0.2l-4,4C22-1.8,9.4,0.9,3.3,10.4c-4.3,6.7-4.3,15.4,0,22.1l-3.1,8.2 c-0.2,0.5,0.1,1.1,0.7,1.2c0.1,0,0.2,0,0.3,0c0.1,0,0.2,0,0.3-0.1l8.2-3.1c9.5,6,22.2,3.2,28.2-6.4c4.2-6.7,4.2-15.2,0-21.9l4-4 C42,6.3,42.1,5.9,42,5.5L42,5.5z" ] [] ]


{-| -}
quiz : Nri.Ui.Svg.V1.Svg
quiz =
    Nri.Ui.Svg.V1.init "0 0 50 46"
        [ Svg.g
            [ Attributes.fill "currentcolor"
            , Attributes.fillRule "evenodd"
            ]
            [ Svg.path [ Attributes.d "M14.4982462,6.96082729 C13.4489636,6.96082729 12.5824213,6.1479217 12.4861388,5.1109714 L12.4881038,4.92459792 C12.4881038,3.80040897 13.3919801,2.88638585 14.5021761,2.88638585 L47.6862288,2.88638585 C49.1756598,2.88638585 49.704231,3.98479975 49.704231,4.92459792 C49.704231,5.86241339 49.1756598,6.96082729 47.6862288,6.96082729 L14.4982462,6.96082729 Z" ] []
            , Svg.path [ Attributes.d "M3.62821246,8.16759261 C3.38347867,8.16759261 3.14731533,8.07246622 2.97019283,7.90095044 L0.294309819,5.31860507 C-0.0861226584,4.95203214 -0.0994544599,4.34379972 0.264313266,3.96041152 C0.626652585,3.57702331 1.2299166,3.56309066 1.61034908,3.93014403 L3.58583638,5.83603502 L8.64192208,0.309575707 C8.99902391,-0.0810190436 9.60133565,-0.105040861 9.98748176,0.254805964 C10.374104,0.615133225 10.3983869,1.2228852 10.0417612,1.61251908 L4.32813204,7.85819161 C4.15434248,8.04796396 3.91341778,8.15894476 3.65773288,8.16711218 C3.64821016,8.16759261 3.63821131,8.16759261 3.62821246,8.16759261" ] []
            , Svg.path [ Attributes.d "M3.62821246,20.0385604 C3.38347867,20.0385604 3.14731533,19.943434 2.97019283,19.7719182 L0.294309819,17.1895728 C-0.0861226584,16.8229999 -0.0994544599,16.2147675 0.264313266,15.8313793 C0.626652585,15.4479911 1.2299166,15.4340584 1.61034908,15.8011118 L3.58583638,17.7070028 L8.64192208,12.1805434 C8.99902391,11.7899487 9.60133565,11.7659269 9.98748176,12.1257737 C10.374104,12.486101 10.3983869,13.0938529 10.0417612,13.4834868 L4.32813204,19.7291593 C4.15434248,19.9189317 3.91341778,20.0299125 3.65773288,20.0380799 C3.64821016,20.0385604 3.63821131,20.0385604 3.62821246,20.0385604" ] []
            , Svg.path [ Attributes.d "M3.62821246,44.6876696 C3.38347867,44.6876696 3.14731533,44.5925432 2.97019283,44.4210274 L0.294309819,41.838682 C-0.0861226584,41.4721091 -0.0994544599,40.8638767 0.264313266,40.4804885 C0.626652585,40.0971003 1.2299166,40.0831676 1.61034908,40.450221 L3.58583638,42.356112 L8.64192208,36.8296527 C8.99902391,36.4390579 9.60133565,36.4150361 9.98748176,36.7748829 C10.374104,37.1352102 10.3983869,37.7429622 10.0417612,38.132596 L4.32813204,44.3782686 C4.15434248,44.5680409 3.91341778,44.6790217 3.65773288,44.6871891 C3.64821016,44.6876696 3.63821131,44.6876696 3.62821246,44.6876696" ] []
            , Svg.path [ Attributes.d "M1.44800241,26.6191349 C0.987920766,26.1548977 0.987920766,25.4678266 1.44800241,25.0035894 C1.90808405,24.5393522 2.58900489,24.5393522 3.04908653,25.0035894 L5.11025229,27.0833722 L7.17141806,25.0035894 C7.6314997,24.5393522 8.39523523,24.5393522 8.84611524,25.0035894 C9.30619688,25.4678266 9.30619688,26.2384604 8.84611524,26.6934129 L6.78494947,28.7731956 L8.84611524,30.8529784 C9.30619688,31.3172156 9.30619688,32.0042867 8.84611524,32.4685239 C8.38603359,32.9327611 7.70511276,32.9327611 7.24503112,32.4685239 L5.18386536,30.3887412 L3.12269959,32.4685239 C2.66261795,32.9327611 1.89888242,32.9327611 1.44800241,32.4685239 C0.987920766,32.0042867 0.987920766,31.2336529 1.44800241,30.7787004 L3.50916817,28.7731956 L1.44800241,26.6191349 Z" ] []
            , Svg.path [ Attributes.d "M14.4982462,18.8670523 C13.4489636,18.8670523 12.5824213,18.0561294 12.4861388,17.0191791 L12.4881038,16.8328057 C12.4881038,15.7086167 13.3919801,14.7926109 14.5021761,14.7926109 L47.6862288,14.7926109 C49.1756598,14.7926109 49.704231,15.8910248 49.704231,16.8328057 C49.704231,17.7706211 49.1756598,18.8670523 47.6862288,18.8670523 L14.4982462,18.8670523 Z" ] []
            , Svg.path [ Attributes.d "M14.4982462,42.6795024 C13.3880502,42.6795024 12.480244,41.7654793 12.478279,40.6393077 C12.478279,39.5210668 13.3821554,38.605061 14.4923514,38.605061 L47.6862288,38.605061 C49.1756598,38.605061 49.704231,39.7034749 49.704231,40.6452558 C49.704231,41.5830712 49.1756598,42.6795024 47.6862288,42.6795024 L14.4982462,42.6795024 Z" ] []
            , Svg.path [ Attributes.d "M14.4982462,30.7732774 C13.3880502,30.7732774 12.480244,29.8572716 12.478279,28.7330826 C12.478279,27.6128591 13.3821554,26.6988359 14.4923514,26.6988359 L47.6862288,26.6988359 C49.1756598,26.6988359 49.704231,27.7952671 49.704231,28.737048 C49.704231,29.6748635 49.1756598,30.7732774 47.6862288,30.7732774 L14.4982462,30.7732774 Z" ] []
            ]
        ]


{-| -}
quickWrite : Nri.Ui.Svg.V1.Svg
quickWrite =
    Nri.Ui.Svg.V1.init "0 0 48 37"
        [ Svg.g
            [ Attributes.fill "currentcolor"
            , Attributes.fillRule "evenodd"
            ]
            [ Svg.path
                [ Attributes.d "M33.427 6.4l-2.666 2.667H0V6.4h33.427zm-5.333 5.333L25.427 14.4H5.867v-2.667h22.227zm-5.333 5.334l-2.667 2.666H2.134v-2.666H22.76zm-4.8 4.8l-2.667 2.666h-8.36v-2.666H17.96zM13.244 29.2l5.556 5.556-7.777 2.221 2.22-7.777zM47.717 5.854l-3.692 3.692-5.5-5.5L42.217.355l5.5 5.5zM14.935 27.558L36.933 5.561l5.5 5.5-21.998 21.997-5.5-5.5z"
                ]
                []
            ]
        ]


{-| -}
guidedDraft : Nri.Ui.Svg.V1.Svg
guidedDraft =
    Nri.Ui.Svg.V1.init "0 0 98 72"
        [ Svg.path [ Attributes.d "M97.801,68.699 L97.80078,68.699 C98.10156,69.3006 98,69.9998 97.60156,70.4998 C97.30076,70.9998 96.70312,71.30058 96.10156,71.30058 L1.800561,71.30058 C1.199001,71.30058 0.601341,70.9998 0.300561,70.4998 C-0.0002189,69.8982 -0.1017789,69.30056 0.199001,68.699 L18.5,28.597 C18.8008,27.89384 19.49998,27.4954 20.1992,27.4954 L41.6992,27.4954 L44.3984,32.6946 C45.1992,34.4914 47,35.593 49,35.593 C50.9024,35.593 52.70316,34.4954 53.6016,32.6946 C53.8008,32.3938 54.9024,30.1946 56.3008,27.4954 L77.8008,27.4954 C78.60156,27.4954 79.19922,27.89778 79.5,28.597 L97.801,68.699 Z M24.60201,47.801 L25.80121,47.801 C26.90277,47.801 27.80121,46.9026 27.80121,45.801 C27.80121,44.69944 26.90281,43.801 25.80121,43.801 L24.60201,43.801 C23.50045,43.801 22.60201,44.6994 22.60201,45.801 C22.60201,46.90256 23.5004,47.801 24.60201,47.801 Z M33.8012,56.1018 L33.80124,56.10174 C34.10206,55.39864 33.69967,54.69943 33.00436,54.39474 C32.9028,54.39474 32.50436,54.19552 32.4028,54.19552 C31.0044,53.49632 29.7036,52.59792 28.7036,51.29712 C28.60594,51.29712 28.40672,50.89868 28.30516,50.79712 C27.90276,50.19556 27.10592,50.0979 26.50436,50.49634 C25.9028,50.89874 25.80514,51.69558 26.20358,52.29714 C26.30514,52.3987 26.70358,52.79714 26.70358,52.8987 C27.90278,54.5979 29.50438,55.79712 31.40278,56.5979 C31.50434,56.5979 32.102,56.89868 32.20356,56.89868 C32.30122,57.00024 32.50044,57.00024 32.602,57.00024 C33.10198,57.00024 33.60198,56.6018 33.8012,56.1018 Z M45.1022,55.80102 L45.10208,55.80104 C45.69974,55.50024 46.00052,54.69944 45.50052,54.19944 C45.19972,53.59788 44.40288,53.39866 43.80132,53.69944 C43.69976,53.801 43.19976,54.00022 43.19976,54.00022 C42.00056,54.60182 40.69976,54.9026 39.19976,55.10182 C39.00056,55.10182 37.90292,55.20338 37.80136,55.20338 C37.10216,55.20338 36.60216,55.80496 36.60216,56.50418 C36.60216,57.20338 37.20374,57.70338 37.90296,57.70338 C37.90296,57.70338 38.60218,57.60182 38.70374,57.60182 C39.00062,57.60182 39.3014,57.50026 39.60218,57.50026 C41.40298,57.30106 43.00458,56.89868 44.40298,56.19946 C44.40298,56.1018 45.00064,55.90258 45.1022,55.80102 Z M53.3014,46.19942 L53.30152,46.19942 C53.69995,45.60172 53.50073,44.80094 53.00464,44.59782 C52.40304,44.19938 51.60228,44.29704 51.20384,44.8986 C51.10618,45.00016 50.8054,45.3986 50.8054,45.50016 C50.40302,46.00016 50.00458,46.5978 49.7038,47.19936 C49.1022,48.10176 48.50456,49.10172 47.903,50.00016 C47.903,50.00016 47.60612,50.3986 47.50456,50.50016 C47.00456,51.10176 47.10222,51.90252 47.70378,52.30096 C48.00456,52.50018 48.20378,52.60174 48.50456,52.60174 C48.903,52.60174 49.20378,52.40252 49.50456,52.10174 C49.60612,52.00018 50.00456,51.60174 50.00456,51.50018 C50.70376,50.50018 51.3014,49.50018 51.90296,48.50018 C52.20374,47.90258 52.60218,47.30098 52.90296,46.80098 C53.00062,46.69942 53.19984,46.30098 53.3014,46.19942 Z M62.6022,41.60172 L62.60202,41.6018 C63.30125,41.6018 63.89891,41.00019 64.09422,40.5041 C64.09422,39.80486 63.49264,39.2033 62.79342,39.2033 L61.99264,39.2033 C61.19584,39.2033 60.39502,39.30096 59.59424,39.40252 C58.29744,39.60174 57.19584,39.90252 56.19584,40.40252 C56.19584,40.40252 55.59818,40.6994 55.49662,40.80096 C54.89506,41.10176 54.59818,41.8986 54.99662,42.50016 C55.19978,42.9025 55.69978,43.10172 56.09822,43.10172 C56.30134,43.10172 56.50056,43.00406 56.69978,42.9025 C56.69978,42.80094 57.19978,42.60172 57.19978,42.60172 C58.00058,42.19938 58.80138,41.9025 59.80138,41.80094 C60.50458,41.70328 61.20376,41.60172 61.90298,41.60172 L62.6022,41.60172 Z M67.3014,42.50016 L67.3014,42.50026 C67.39906,42.50026 67.8014,42.80104 67.8014,42.9026 C69.8014,43.9026 70.70376,45.30102 71.1022,46.1018 C71.1022,46.19946 71.30142,46.50024 71.30142,46.50024 C71.50062,47.00024 72.00062,47.30102 72.50062,47.30102 C72.59828,47.30102 72.7975,47.30102 72.89906,47.19946 C73.59828,46.99626 73.89906,46.29708 73.69984,45.59786 C73.69984,45.59786 73.39906,45.0002 73.39906,44.89864 C72.89906,43.89864 71.59826,41.99624 69.09826,40.59784 C69.09826,40.50018 68.5006,40.30096 68.39904,40.1994 C67.80144,39.90252 67.00062,40.1994 66.69984,40.80096 C66.40296,41.39856 66.69984,42.19938 67.3014,42.50016 Z M76.6998,56.00016 L76.69974,56.00016 C77.19974,55.39866 77.19974,54.60177 76.49662,54.09786 L74.79742,52.59786 L76.19582,50.89866 C76.59816,50.39866 76.4966,49.59786 75.9966,49.09786 C75.4966,48.69552 74.6958,48.79708 74.1958,49.29708 L72.895,50.89868 L71.4966,49.59788 C70.9966,49.09788 70.1958,49.19944 69.6958,49.69944 C69.1958,50.19944 69.29736,51.00024 69.79736,51.50024 L71.29736,52.89864 L69.89896,54.59784 C69.49662,55.09784 69.59818,55.89864 70.09818,56.39864 C70.2974,56.59786 70.59818,56.69942 70.89896,56.69942 C71.2974,56.69942 71.59818,56.5002 71.89896,56.19942 L73.19976,54.59782 L74.80136,56.09782 C75.09824,56.29704 75.39902,56.3986 75.6998,56.3986 C76.09824,56.3986 76.39902,56.30094 76.6998,56.00016 Z" ] []
        , Svg.path [ Attributes.d "M47.602,31.199 L47.6023,31.1986 C47.6023,31.1986 42.2,20.6008 39.7,15.6946 C37.2,10.7966 39.2,4.3982 44.3016,1.7966 C49.3988,-0.801 55.598,1.2966 58.1996,6.3982 C59.6996,9.3982 59.6996,12.8006 58.1996,15.699 C56.6996,18.699 50.3012,31.199 50.3012,31.199 C49.8012,32.3006 48.20356,32.3006 47.602,31.199 Z M49.0004,5.601 C46.0004,5.601 43.602,8.101 43.602,10.9994 C43.602,13.9994 46.0004,16.3978 49.0004,16.3978 C52.0004,16.3978 54.3988,13.9994 54.3988,10.9994 C54.3988,7.9994 52.0004,5.601 49.0004,5.601 Z" ] []
        ]


{-| -}
selfReview : Nri.Ui.Svg.V1.Svg
selfReview =
    Nri.Ui.Svg.V1.init "0 -7 64 84"
        [ Svg.path [ Attributes.d "M62.16365,17.60935 C62.57365,17.60935 62.97265,17.76935 63.26565,18.06235 C63.55865,18.35535 63.72265,18.75035 63.72565,19.16435 C63.72565,38.98435 50.33265,55.21435 33.56165,56.16835 L33.56165,73.66435 L40.98365,73.66435 C41.84765,73.66435 42.54665,74.36335 42.54665,75.22635 C42.54665,76.08935 41.84765,76.78935 40.98365,76.78935 L22.82065,76.78935 C21.95665,76.78935 21.25765,76.08935 21.25765,75.22635 C21.25765,74.36335 21.95665,73.66435 22.82065,73.66435 L30.43765,73.66435 L30.43765,56.16835 C13.66465,55.21435 0.27365,38.98835 0.27365,19.16435 C0.27765,18.75035 0.44165,18.35535 0.73465,18.06235 C1.02765,17.76935 1.42565,17.60935 1.83565,17.60935 L8.17165,17.60935 L8.17165,20.73435 L3.42965,20.73435 C4.12065,38.70335 16.67165,53.10535 31.99965,53.10535 C47.32765,53.10535 59.87865,38.70335 60.56965,20.73435 L55.43665,20.73435 L55.43665,17.60935 L62.16365,17.60935 Z", Attributes.fill "currentcolor" ] []
        , Svg.path [ Attributes.d "M31.99955,37.54295 C23.45655,37.54295 16.50755,29.24195 16.50755,19.03495 C16.50755,8.83195 23.45655,0.52695 31.99955,0.52695 C40.54255,0.52695 47.49155,8.83195 47.49155,19.03495 C47.49155,29.23795 40.54255,37.54295 31.99955,37.54295 Z M35.83955,15.34395 L35.83955,15.34795 C36.44855,14.73495 36.44855,13.74695 35.83955,13.13695 C35.22655,12.52795 34.23755,12.52795 33.62855,13.13695 L27.34755,19.41795 C26.73755,20.02795 26.73755,21.01595 27.34755,21.62595 C27.96055,22.23895 28.94855,22.23895 29.55855,21.62595 L35.83955,15.34395 Z M20.73755,12.80495 C20.12755,13.41795 20.12755,14.40695 20.73755,15.01595 C21.34655,15.62595 22.33855,15.62595 22.94855,15.01595 L29.22955,8.73895 C29.83855,8.12595 29.83855,7.13695 29.22955,6.52795 C28.61655,5.91795 27.62755,5.91795 27.01855,6.52795 L20.73755,12.80495 Z M21.83855,18.31295 L21.83855,18.31695 C21.22955,18.92595 21.22955,19.91495 21.83855,20.52395 C22.44855,21.13695 23.44055,21.13695 24.04955,20.52395 L34.73755,9.83995 C35.34755,9.23095 35.34755,8.23795 34.73755,7.62895 C34.12855,7.01995 33.13655,7.01995 32.52655,7.62895 L21.83855,18.31295 Z", Attributes.fill "currentcolor" ] []
        , Svg.mask [ Attributes.fill "currentcolor" ] [ Svg.path [ Attributes.d "M31.99955,44.85935 C20.03055,44.85935 10.29255,33.27335 10.29255,19.03535 C10.29255,4.79735 20.03055,-6.78865 31.99955,-6.78865 C43.96855,-6.78865 53.70655,4.79735 53.70655,19.03535 C53.70655,33.27335 43.96855,44.85935 31.99955,44.85935 Z M31.99955,-2.59765 C21.73355,-2.59765 13.38255,7.10535 13.38255,19.03535 C13.38255,30.96435 21.73355,40.66835 31.99955,40.66835 C42.26555,40.66835 50.61655,30.96535 50.61655,19.03535 C50.61655,7.10535 42.26555,-2.59765 31.99955,-2.59765 Z" ] [] ]
        , Svg.path [ Attributes.d "M31.99955,44.85935 C20.03055,44.85935 10.29255,33.27335 10.29255,19.03535 C10.29255,4.79735 20.03055,-6.78865 31.99955,-6.78865 C43.96855,-6.78865 53.70655,4.79735 53.70655,19.03535 C53.70655,33.27335 43.96855,44.85935 31.99955,44.85935 Z M31.99955,-2.59765 C21.73355,-2.59765 13.38255,7.10535 13.38255,19.03535 C13.38255,30.96435 21.73355,40.66835 31.99955,40.66835 C42.26555,40.66835 50.61655,30.96535 50.61655,19.03535 C50.61655,7.10535 42.26555,-2.59765 31.99955,-2.59765 Z", Attributes.fill "currentcolor" ] []
        ]


{-| -}
dailyWriting : Nri.Ui.Svg.V1.Svg
dailyWriting =
    Nri.Ui.Svg.V1.init
        "0 0 39 39"
        [ Svg.g
            [ Attributes.clipPath "url(#clip0_220_913)"
            ]
            [ Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M39 9.46527V34.9254C38.6825 36.8809 37.218 38.4704 35.3117 39H3.75242C1.59263 38.3999 0 36.4394 0 34.1275V10.2632C0 7.47747 2.31232 5.20185 5.14297 5.20185H10.4256V1.34704C10.4256 0.604805 11.0401 0 11.7944 0C12.5486 0 13.1631 0.604805 13.1631 1.34704V5.20185H25.901V1.34704C25.901 0.604805 26.5156 0 27.2698 0C28.024 0 28.6386 0.604805 28.6386 1.34704V5.20185H33.9212C36.4761 5.20185 38.6088 7.05573 39 9.46527ZM5.14297 7.89285H10.4256V9.75C10.4256 10.4929 11.0401 11.097 11.7944 11.097C12.5486 11.097 13.1631 10.4929 13.1631 9.75V7.89285H25.8545V9.75C25.8545 10.4929 26.4684 11.097 27.2233 11.097C27.9775 11.097 28.5914 10.4929 28.5914 9.75V7.89285H33.8746C35.1962 7.89285 36.2801 8.96195 36.2801 10.2607V14.763H2.73755V10.2607C2.73755 8.96195 3.82074 7.89285 5.14297 7.89285ZM33.9212 36.4953H5.14297C3.82074 36.4953 2.73755 35.2718 2.73755 33.7855V14.763H36.3266V33.7855C36.3266 35.2718 35.2434 36.4953 33.9212 36.4953Z"
                , Attributes.fill "currentcolor"
                ]
                []
            , Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M9.32752 13.8667L11.7735 13.8704C12.4281 13.8771 12.9625 14.37 12.9609 14.9675L12.9322 28.8335C12.9322 29.0532 12.8709 29.2685 12.7563 29.46L10.8545 32.57C10.7833 32.6836 10.6516 32.7563 10.5084 32.76C10.3619 32.7578 10.2277 32.6843 10.1573 32.5685L8.26615 29.4503C8.1524 29.2596 8.09267 29.0436 8.09427 28.8261L8.12376 14.9586C8.12376 14.3566 8.66386 13.866 9.32752 13.8667ZM9.51491 15.0387C9.48627 15.0387 9.45681 15.0417 9.43635 15.0454C9.23259 15.087 9.08693 15.2525 9.08938 15.444L9.09839 28.8513C9.09839 28.9337 9.12948 29.0154 9.18431 29.0799L9.20559 29.1044L10.0607 30.5221H10.9993L11.9175 29.0146C11.9511 28.9604 11.9691 28.8944 11.9691 28.8291V28.5596C11.5378 28.6524 11.0959 28.6992 10.654 28.6992L10.5697 28.6984C10.492 28.6984 10.4208 28.6962 10.3684 28.694L9.93226 28.6932V15.421C9.93389 15.3193 9.89052 15.2243 9.81114 15.1523C9.72931 15.0781 9.62702 15.0387 9.51491 15.0387Z"
                , Attributes.fill "currentcolor"
                ]
                []
            , Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M15.6905 31.9008C15.2094 31.9008 14.8174 31.5445 14.8174 31.1066C14.8174 30.6709 15.2077 30.3146 15.6881 30.3146H20.9654C21.6095 30.3146 21.8386 30.7422 21.8386 31.1081C21.8386 31.474 21.6095 31.9008 20.9654 31.9008H15.6905Z"
                , Attributes.fill "currentcolor"
                ]
                []
            , Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M15.6905 26.987C15.2102 26.987 14.8182 26.6315 14.8174 26.1928C14.8174 25.7571 15.2077 25.4016 15.6881 25.4016H30.0325C30.6765 25.4016 30.9056 25.8284 30.9056 26.1943C30.9056 26.5602 30.6765 26.987 30.0325 26.987H15.6905Z"
                , Attributes.fill "currentcolor"
                ]
                []
            , Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M15.6905 21.8775C15.2102 21.8775 14.8182 21.5219 14.8174 21.0833C14.8174 20.6476 15.2077 20.292 15.6881 20.292H30.0325C30.6765 20.292 30.9056 20.7188 30.9056 21.0848C30.9056 21.4507 30.6765 21.8775 30.0325 21.8775H15.6905Z"
                , Attributes.fill "currentcolor"
                ]
                []
            , Svg.path
                [ Attributes.fillRule "evenodd"
                , Attributes.clipRule "evenodd"
                , Attributes.d "M15.6903 16.966C15.2362 16.966 14.8622 16.6491 14.8213 16.246V16.1733C14.8213 15.7361 15.2116 15.3798 15.692 15.3798H30.0323C30.6763 15.3798 30.9054 15.8073 30.9054 16.1733C30.9054 16.5392 30.6763 16.966 30.0323 16.966H15.6903Z"
                , Attributes.fill "currentcolor"
                ]
                []
            ]
        , Svg.defs []
            [ Svg.clipPath
                [ Attributes.id "clip0_220_913"
                ]
                [ Svg.rect
                    [ Attributes.width "39"
                    , Attributes.height "39"
                    , Attributes.fill "white"
                    ]
                    []
                ]
            ]
        ]


{-| -}
novels : Nri.Ui.Svg.V1.Svg
novels =
    Nri.Ui.Svg.V1.init "0 0 41 39"
        [ Svg.path
            [ Attributes.fill "currentcolor"
            , Attributes.d "M3.21249 33.6C3.59687 34.1719 4.37029 34.325 4.94373 33.9438C7.13125 32.4813 9.70293 31.7 12.3345 31.7C14.9658 31.7 17.5377 32.4812 19.7253 33.9438C19.93 34.0813 20.1722 34.1563 20.4191 34.1563H20.5691C20.8191 34.1594 21.066 34.0875 21.2753 33.95C23.4613 32.4828 26.0333 31.7 28.6661 31.7C31.2989 31.7 33.8709 32.4828 36.0569 33.95C36.2632 34.0844 36.5038 34.1563 36.7507 34.1563C37.1194 34.1609 37.4695 34.0031 37.7101 33.725C37.9522 33.4469 38.0585 33.0766 38.0007 32.7125V32.5188V9.37518C38.0007 8.95954 37.7944 8.5705 37.4507 8.33766C34.9554 6.66578 32.0367 5.74078 29.0351 5.6689C26.0335 5.59702 23.0727 6.38138 20.5007 7.93138C17.9272 6.3923 14.9695 5.61574 11.9711 5.69386C8.9742 5.77042 6.06027 6.69854 3.56947 8.36886C3.21791 8.59698 3.00383 8.98762 3.00071 9.40638V32.5V32.7C2.95384 33.0156 3.0304 33.3375 3.21321 33.6L3.21249 33.6ZM35.5001 10.0752V30.7376C31.1517 28.647 26.0845 28.6626 21.7501 30.7814V10.075C23.8267 8.82807 26.2033 8.16871 28.6253 8.16871C31.0473 8.16871 33.4237 8.82807 35.5005 10.075L35.5001 10.0752ZM12.3753 8.2002C14.7956 8.1877 17.1721 8.83612 19.2505 10.0752V30.8C14.9161 28.6812 9.84889 28.6656 5.50049 30.7562V10.0938C7.57549 8.84385 9.95369 8.18449 12.3757 8.18761L12.3753 8.2002Z"
            ]
            []
        ]


{-| -}
submitting : Nri.Ui.Svg.V1.Svg
submitting =
    Nri.Ui.Svg.V1.init "0 0 25 25"
        [ Svg.path
            [ Attributes.fillOpacity ".5"
            , Attributes.d "M0 1.875v1.406h22.5V1.875H0zm0 3.867v1.406h24.32V5.742H0zM0 9.61v1.407h15.117V9.609H0zm0 5.625v1.407h24.32v-1.407H0zm0 3.868v1.406h23.125v-1.406H0zm0 3.867v1.406h13.75v-1.406H0z"
            ]
            []
        , Svg.path
            [ Attributes.fill "#FFF"
            , Attributes.d "M13.15 23.552l.867-5.111 6.325-12.527 1.15-.069.71-1.69 1.909.877-.702 1.715.338.924-6.827 12.878-3.178 3.069z"
            ]
            []
        , Svg.path
            [ Attributes.d "M24.32 5.78a.906.906 0 0 0-.405-1.249l-1.181-.602c-.237-.12-.444-.151-.711-.064-.268.087-.417.234-.538.47l-.481.945c-.178.058-.297-.002-.475.056-.267.087-.417.234-.537.47l-.662 1.3-.945-.482a.453.453 0 0 0-.624.203l-3.01 5.906a.453.453 0 0 0 .203.624c.058.179.236.12.325.092.09-.03.268-.087.328-.205l2.74-5.523.472.24-5.477 10.75c-.06.118-.031.208-.091.326l-.625 4.146c-.062.414.143.742.526 1.012.236.12.444.151.711.064.178-.058.268-.087.328-.205l2.987-2.942c.089-.029.15-.147.21-.265l6.62-12.995a.997.997 0 0 0-.169-1.127l.482-.945zm-2.008-1.024l1.182.602-.482.945-1.181-.602.481-.945zm-8.739 18.612l.591-3.642 2.127 1.083-2.718 2.559zm3.228-3.415L14.44 18.75l4.695-9.214 2.362 1.204-4.695 9.214zm5.116-10.041l-2.362-1.204 1.264-2.48 2.363 1.203-1.265 2.48z"
            ]
            []
        ]


{-| -}
rating : Nri.Ui.Svg.V1.Svg
rating =
    Nri.Ui.Svg.V1.init "0 0 25 25"
        [ Svg.path
            [ Attributes.fillRule "evenodd"
            , Attributes.d "M4.961 19.785h-1.59C1.526 19.785 0 18.258 0 16.415V6.079c0-1.845 1.527-3.371 3.371-3.371H13.77c.318 0 .573.255.573.573a.571.571 0 0 1-.573.573H3.37c-1.21 0-2.195.986-2.195 2.195v10.336c0 1.21.986 2.195 2.195 2.195h2.194c.318 0 .574.255.574.573v3.56l4.165-4.006a.604.604 0 0 1 .415-.159h9.603c.891 0 1.718-.573 2.067-1.4a.586.586 0 0 1 .764-.318.586.586 0 0 1 .318.764 3.425 3.425 0 0 1-3.149 2.13h-9.35l-4.992 4.77a.604.604 0 0 1-.415.16c-.062 0-.159 0-.221-.032-.257-.035-.383-.257-.383-.48v-4.357zm20.036-11.99v.159l-.923 5.724c-.19 1.463-1.24 2.323-2.8 2.323h-6.806a2.36 2.36 0 0 1-1.652-.668c-.19.16-.446.255-.733.255H9.857a1.14 1.14 0 0 1-1.144-1.144V7.319a1.14 1.14 0 0 1 1.144-1.144h2.226c.35 0 .636.159.858.381h.032c.096-.032 2.513-.732 2.513-2.766V1.024c0-.255.159-.477.413-.54.064-.032 1.463-.446 2.482.318.636.477.985 1.272.985 2.385v2.29h3.212c1.368-.067 2.419.983 2.419 2.318zm-12.88-.509H9.922v7.124h2.195V7.286zm11.733.509c0-.7-.54-1.24-1.24-1.24h-3.785a.572.572 0 0 1-.573-.574V3.12c0-.699-.16-1.209-.509-1.431-.318-.222-.732-.255-1.017-.222v2.289c0 2.925-3.212 3.848-3.339 3.88h-.032v5.946c0 .667.54 1.24 1.241 1.24h6.806c1.494 0 1.622-.985 1.653-1.303v-.032l.795-5.691z"
            ]
            []
        ]


{-| -}
revising : Nri.Ui.Svg.V1.Svg
revising =
    Nri.Ui.Svg.V1.init "0 0 25 25"
        [ Svg.path
            [ Attributes.d "M23.056 12.001h.58C23.637 5.893 18.64.926 12.5.926a11.169 11.169 0 0 0-10.214 6.66L0 7.128 1.652 12 5.07 8.142l-2.206-.44C4.93 3.184 9.831.71 14.668 1.74c4.837 1.03 8.32 5.291 8.388 10.261zM12.5 23.49a10.593 10.593 0 0 0 9.637-6.215l-2.206-.441 3.417-3.858L25 17.845l-2.286-.457a11.169 11.169 0 0 1-10.214 6.66c-6.14 0-11.137-4.968-11.137-11.073h.581c.03 5.833 4.754 10.537 10.556 10.514z"
            ]
            []
        , Svg.path
            [ Attributes.fillOpacity ".5"
            , Attributes.d "M5.833 13.348v1.068h13.555v-1.068H5.833zm0 2.938v1.068h12.652v-1.068H5.833zm0 2.938v1.068H11.4v-1.068H5.833z"
            ]
            []
        , Svg.path
            [ Attributes.fill "#FFF"
            , Attributes.d "M10.958 19.656l.648-3.88 4.769-9.505.87-.051.533-1.282 1.445.668-.529 1.301.257.702-5.147 9.77-2.4 2.328z"
            ]
            []
        , Svg.path
            [ Attributes.d "M19.382 6.173a.691.691 0 0 0-.308-.948l-.894-.458a.642.642 0 0 0-.537-.05.642.642 0 0 0-.406.356l-.363.717c-.135.044-.224-.002-.359.042a.642.642 0 0 0-.406.356l-.499.986-.715-.366a.341.341 0 0 0-.472.153l-2.268 4.482a.346.346 0 0 0 .154.474c.044.135.179.091.246.07.067-.022.202-.066.248-.156l2.065-4.19.357.183-4.129 8.156c-.045.09-.023.158-.068.247l-.468 3.148c-.046.315.11.564.4.769a.642.642 0 0 0 .537.05c.135-.044.202-.066.247-.156L14 17.808c.067-.022.112-.112.158-.201l4.99-9.86a.76.76 0 0 0-.129-.856l.363-.718zm-1.52-.779l.895.459-.363.717-.894-.459.363-.717zm-6.585 14.122l.442-2.765 1.61.826-2.052 1.94zm2.436-2.589l-1.787-.917 3.539-6.99 1.788.916-3.54 6.991zM17.57 9.31l-1.788-.917.953-1.883 1.788.917-.953 1.883z"
            ]
            []
        ]


{-| -}
startPrimary : Nri.Ui.Svg.V1.Svg
startPrimary =
    let
        toIcon circle =
            [ circle
            , Svg.path [ Attributes.fill "#fff", Attributes.d "M21.0869565,33.8146977 C20.6577447,34.0617674 20.1248751,34.0617674 19.6956522,33.8146977 C19.2664403,33.5683165 19,33.1074898 19,32.61405 L19,17.38595 C19,16.889723 19.2664403,16.4316724 19.6956522,16.1853023 C20.1248751,15.9382326 20.6577447,15.9382326 21.0869565,16.1853023 L34.3043478,23.8007347 C34.7335708,24.0478044 35,24.5051666 35,25.002082 C35,25.4955219 34.7363534,25.9535725 34.3043478,26.1999537 L21.0869565,33.8146977 Z" ] []
            ]
    in
    encircle 50 toIcon


{-| -}
startSecondary : Nri.Ui.Svg.V1.Svg
startSecondary =
    Nri.Ui.Svg.V1.init "0 60 50 51"
        [ Svg.g [ Attributes.transform "translate(0.000000, 60.000000)" ]
            [ Svg.path
                [ Attributes.d "M0,25.3650791 C0,39.1738284 11.19375,50.3650803 25,50.3650803 C38.80875,50.3650803 50,39.1738284 50,25.3650791 C50,11.5588298 38.80625,0.365080324 25,0.365080324 C11.19375,0.365080324 0,11.5588298 0,25.3650791 Z"
                , Attributes.fill "#fff"
                ]
                []
            , Svg.path
                [ Attributes.stroke "currentcolor"
                , Attributes.strokeWidth "3"
                , Attributes.d "M1.5,25.3650791 C1.5,38.3445152 12.021291,48.8650803 25,48.8650803 C37.9803224,48.8650803 48.5,38.3454018 48.5,25.3650791 C48.5,12.3872569 37.9778229,1.86508032 25,1.86508032 C12.0221771,1.86508032 1.5,12.3872569 1.5,25.3650791 Z"
                , Attributes.fill "none"
                ]
                []
            , Svg.path
                [ Attributes.fill "currentcolor"
                , Attributes.d "M20.946522,34.4104003 C20.5071165,34.6639342 19.9615913,34.6639342 19.5221743,34.4104003 C19.0827687,34.1575729 18.8100004,33.6846894 18.8100004,33.1783395 L18.8100004,17.5518211 C18.8100004,17.0426111 19.0827687,16.5725764 19.5221743,16.3197604 C19.9615913,16.0662265 20.5071165,16.0662265 20.946522,16.3197604 L34.4778257,24.1344382 C34.9172427,24.3879721 35.1899996,24.8573004 35.1899996,25.3672168 C35.1899996,25.8735667 34.9200914,26.3436015 34.4778257,26.5964289 L20.946522,34.4104003 Z"
                ]
                []
            ]
        ]


{-| -}
assessment : Nri.Ui.Svg.V1.Svg
assessment =
    let
        toIcon circle =
            [ Svg.g
                [ Attributes.fillRule "evenodd"
                ]
                [ circle
                , Svg.path [ Attributes.d "M21.2420883,54.5992195 C23.8522257,54.5992195 25.9681602,52.483285 25.9681602,49.8731476 L25.9681602,43.8936083 C25.9681602,41.2834709 23.8522257,39.1675364 21.2420883,39.1675364 C18.6319509,39.1675364 16.5160164,41.2834709 16.5160164,43.8936083 L16.5160164,49.8731476 C16.5160164,52.483285 18.6319509,54.5992195 21.2420883,54.5992195 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M33.0968983,54.5992195 C35.6645087,54.5992195 37.7459682,52.51776 37.7459682,49.9501496 L37.7459682,34.344137 C37.7459682,31.7765266 35.6645087,29.695067 33.0968983,29.695067 C30.5292879,29.695067 28.4478284,31.7765266 28.4478284,34.344137 L28.4478284,49.9501496 C28.4478284,52.51776 30.5292879,54.5992195 33.0968983,54.5992195 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M49.6798336,22.361242 L49.6798336,49.872327 C49.6798336,52.4829181 47.5635314,54.5992203 44.9529404,54.5992203 C42.3423493,54.5992203 40.2260471,52.4829181 40.2260471,49.872327 L40.2260471,22.361242 L40.2260471,22.361242 L36.2823138,22.361242 L45.0305583,13.1240141 L53.6231562,22.361242 L49.6798336,22.361242 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
practiceCircled : Nri.Ui.Svg.V1.Svg
practiceCircled =
    let
        toIcon circle =
            [ Svg.g
                [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M56.9478,17.876 C56.8298,17.527 56.5288,17.271 56.1598,17.22 L52.5988,16.712 L52.0918,13.151 C52.0368,12.785 51.7828,12.48 51.4348,12.362 C51.0868,12.244 50.6978,12.335 50.4378,12.6 L46.4298,16.607 C43.1488,14.518 39.3778,13.4 35.4578,13.4 C24.1788,13.4 15.0028,22.577 15.0028,33.856 C15.0028,37.719 16.1048,41.483 18.1928,44.773 L15.0668,52.992 C14.9318,53.352 15.0168,53.757 15.2908,54.027 C15.4768,54.214 15.7268,54.312 15.9808,54.312 C16.0988,54.312 16.2138,54.291 16.3248,54.247 L24.5438,51.122 C27.8308,53.208 31.5948,54.312 35.4618,54.312 C46.7408,54.312 55.9168,45.136 55.9168,33.856 C55.9168,29.933 54.8008,26.161 52.7108,22.881 L56.7188,18.873 C56.9718,18.612 57.0628,18.228 56.9478,17.876 L56.9478,17.876 Z M50.4378,15.353 L50.7048,17.226 L47.8158,20.114 L47.5498,18.237 L50.4378,15.353 Z M41.0218,23.213 L41.4848,26.445 L39.9968,27.934 C38.7388,26.967 37.1658,26.382 35.4578,26.382 C31.3418,26.382 27.9898,29.733 27.9898,33.85 C27.9898,37.966 31.3418,41.317 35.4578,41.317 C39.5738,41.317 42.9258,37.966 42.9258,33.85 C42.9258,32.142 42.3438,30.568 41.3738,29.311 L42.8618,27.822 L46.0978,28.282 C46.9938,29.994 47.4708,31.904 47.4708,33.85 C47.4708,40.475 42.0838,45.862 35.4578,45.862 C28.8328,45.862 23.4448,40.475 23.4448,33.85 C23.4448,27.224 28.8358,21.836 35.4578,21.836 C37.3988,21.843 39.3138,22.32 41.0218,23.213 L41.0218,23.213 Z M40.9748,33.856 C40.9748,36.9 38.4988,39.376 35.4548,39.376 C32.4098,39.376 29.9348,36.9 29.9348,33.856 C29.9348,30.812 32.4098,28.337 35.4548,28.337 C36.6258,28.337 37.7108,28.705 38.6038,29.327 L35.1748,32.757 C34.6828,32.882 34.3188,33.325 34.3188,33.853 C34.3188,34.479 34.8258,34.989 35.4548,34.989 C35.9858,34.989 36.4288,34.624 36.5538,34.13 L39.9838,30.7 C40.6058,31.6 40.9748,32.686 40.9748,33.856 L40.9748,33.856 Z M46.0948,21.839 L43.2068,24.728 L42.9398,22.851 L45.8278,19.962 L46.0948,21.839 Z M46.4598,26.371 L44.5868,26.105 L47.4748,23.216 L49.3488,23.482 L46.4598,26.371 Z M35.4578,52.363 C31.8118,52.363 28.2638,51.277 25.1998,49.225 C24.9368,49.049 24.6078,49.012 24.3098,49.123 L17.6538,51.653 L20.1838,45 C20.2958,44.706 20.2588,44.374 20.0828,44.111 C18.0298,41.044 16.9438,37.499 16.9438,33.853 C16.9438,23.648 25.2468,15.346 35.4508,15.346 C38.8538,15.346 42.1348,16.269 45.0128,18.015 L41.6718,21.355 C39.7468,20.398 37.6158,19.892 35.4508,19.892 C27.7538,19.892 21.4898,26.154 21.4898,33.853 C21.4898,41.551 27.7538,47.814 35.4508,47.814 C43.1488,47.814 49.4128,41.551 49.4128,33.853 C49.4128,31.688 48.9058,29.554 47.9478,27.63 L51.2898,24.288 C53.0348,27.169 53.9578044,30.45 53.9578044,33.853 C53.9648,44.06 45.6618,52.363 35.4578,52.363 L35.4578,52.363 Z M51.0698,21.762 L49.1958,21.495 L52.0848,18.606 L53.9578,18.873 L51.0698,21.762 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
standards : Nri.Ui.Svg.V1.Svg
standards =
    Nri.Ui.Svg.V1.init "0 0 70 70"
        [ Svg.g
            [ Attributes.fillRule "evenodd" ]
            [ Svg.circle [ Attributes.fill "#FFFFFF", Attributes.cx "35", Attributes.cy "35", Attributes.r "27" ] []
            , Svg.path [ Attributes.d "M35,0 C25.7166,0 16.814,3.68865 10.2515,10.2515 C3.689,16.81435 0,25.7173 0,35 C0,44.2827 3.68865,53.186 10.2515,59.7485 C16.81435,66.311 25.7173,70 35,70 C44.2827,70 53.186,66.31135 59.7485,59.7485 C66.311,53.18565 70,44.2827 70,35 C70,25.7173 66.31135,16.8161 59.7485,10.2515 C53.186,3.689 44.2827,0 35,0 Z M16.47751,48.90186 C15.922431,47.56472 16.228681,46.02255 17.25136,44.99992 C18.27672,43.97456 19.81623,43.66831 21.1533,44.22334 C22.49317,44.778419 23.36544,46.08268 23.36544,47.53196 C23.36544,48.48081 22.988098,49.3913 22.31544,50.064 C21.645519,50.733921 20.73498,51.11127 19.7834,51.11127 C18.33692,51.11127 17.02988,50.23893 16.47751,48.90186 Z M16.47751,36.37046 C15.922431,35.03332 16.228681,33.49388 17.25136,32.46852 C18.27672,31.44589 19.81623,31.13964 21.1533,31.69194 C22.49317,32.247019 23.36544,33.55128 23.36544,35.00056 C23.36544,35.94941 22.988098,36.8599 22.31544,37.5326 C21.645519,38.202521 20.73498,38.57987 19.7834,38.57987 C18.33692,38.57987 17.02988,37.70753 16.47751,36.37046 Z M16.47751,23.83899 C15.922431,22.50185 16.228681,20.96241 17.25136,19.93705 C18.27672,18.91442 19.81623,18.60817 21.1533,19.1632 C22.49317,19.715542 23.36544,21.02254 23.36544,22.46909 C23.36544,23.42067 22.988098,24.33123 22.31544,25.00113 C21.645519,25.673788 20.73498,26.05113 19.7834,26.05113 C18.33692,26.05113 17.02988,25.17886 16.47751,23.83899 Z M30.5242,51.11183 C28.54999,51.1091 26.94762,49.50673 26.94762,47.53252 C26.94762,45.55558 28.54999,43.95321 30.5242,43.95048 L50.2173,43.95048 C51.16615,43.95048 52.07944,44.327822 52.75207,44.99775 C53.421991,45.670408 53.80207,46.58094 53.80207,47.53252 C53.80207,48.48137 53.421991,49.39466 52.75207,50.06456 C52.079412,50.737218 51.16615,51.11183 50.2173,51.11183 L30.5242,51.11183 Z M50.2145,38.5777 L30.5242,38.58043 C28.54726,38.58043 26.94489,36.97806 26.94489,35.00112 C26.94489,33.02418 28.54726,31.42181 30.5242,31.42181 L50.2173,31.42181 C52.19424,31.42181 53.79661,33.02418 53.79661,35.00112 C53.79661,36.97806 52.19424,38.58043 50.2173,38.58043 L50.2145,38.5777 Z M50.2145,26.0463 L30.5242,26.051767 C28.54999,26.04903 26.94762,24.446667 26.94762,22.469727 C26.94762,20.495517 28.54999,18.893147 30.5242,18.890417 L50.2173,18.890417 C51.16615,18.890417 52.07944,19.265029 52.75207,19.937687 C53.421991,20.607608 53.80207,21.520877 53.80207,22.469727 C53.80207,23.421307 53.421991,24.331867 52.75207,25.004497 C52.079412,25.674418 51.16615,26.051767 50.2173,26.051767 L50.2145,26.0463 Z", Attributes.fill "currentcolor" ] []
            ]
        ]


{-| -}
modules : Nri.Ui.Svg.V1.Svg
modules =
    let
        toIcon circle =
            [ Svg.g
                [ Attributes.fillRule "evenodd"
                ]
                [ circle
                , Svg.path
                    [ Attributes.d "M148.732834,119.223188 L148.732834,97.2008439 C148.732834,96.9884308 148.703867,96.7760301 148.645944,96.5732812 L148.645944,96.4236355 C148.592841,96.2498543 148.515602,96.0857124 148.423879,95.926415 L148.423879,95.8539958 C148.31284,95.6802022 148.177679,95.5257245 148.028033,95.3857306 L147.916994,95.2891882 L147.916994,95.2843561 C147.777,95.1684979 147.622523,95.0719431 147.458393,94.9898845 L147.395638,94.9898845 L127.723827,85.9046171 L127.723827,71.6778366 L127.723827,71.6826687 C127.723827,70.7992539 127.250742,69.9834137 126.488005,69.5440791 L111.769368,61.202282 L111.769368,44.8523598 C111.759716,44.6399467 111.721097,44.427546 111.658341,44.219965 L111.658341,44.0703194 L111.658341,44.0751391 C111.600406,43.9061775 111.527999,43.742048 111.436277,43.5924024 L111.436277,43.5055117 C111.32525,43.3365502 111.190076,43.1820725 111.040431,43.0469106 L110.929392,42.9503682 C110.789398,42.8345099 110.63492,42.7331355 110.470791,42.6510646 L110.408036,42.6510646 L90.4655797,33.4451809 C89.8090493,33.1458772 89.0560013,33.1458772 88.3994092,33.4451809 L68.5150366,42.6173266 L68.4522816,42.6173266 C68.2881521,42.6993852 68.1384941,42.7959399 67.9985002,42.9117982 L67.887474,43.0083406 L67.8826419,43.0131727 C67.7329962,43.1483469 67.6026541,43.3076443 67.4916155,43.4814379 L67.4916155,43.5538447 C67.3950731,43.7131545 67.322654,43.877284 67.264731,44.0510653 L67.264731,44.2007109 L67.264731,44.1958912 C67.2116277,44.4034722 67.1826724,44.6158729 67.1826724,44.8282859 L67.1826724,61.2412351 L52.352811,69.8919876 C51.5852544,70.3312852 51.1169892,71.1470883 51.1169892,72.0257575 L51.1169892,85.8175287 L51.0300862,85.8175287 C50.3735559,85.518225 49.6205079,85.518225 48.9639157,85.8175287 L29.0412364,94.9509932 L28.9784789,94.9509932 L28.983306,94.9509932 C28.8191765,95.0330518 28.6646988,95.1344386 28.5247049,95.2502969 L28.4136737,95.3468393 C28.2640281,95.4868332 28.1288539,95.646143 28.0178277,95.8151045 L28.0178277,95.8923434 C27.9261074,96.0468211 27.8488661,96.2109506 27.7957628,96.3847442 L27.7957628,96.5343899 C27.7378337,96.7371388 27.7085718,96.9495519 27.7085718,97.1619526 L27.7085718,119.223843 C27.6943871,120.160361 28.2109211,121.029255 29.041208,121.45895 L48.9107507,130.616637 L48.9155828,130.616637 C49.5721131,130.92076 50.3251611,130.92076 50.9769335,130.616637 L59.7532455,126.527797 L88.389708,142.887606 C89.1524449,143.331736 90.0937827,143.331736 90.8613516,142.887606 L117.83687,127.145708 L125.386999,130.616637 C126.04353,130.92076 126.796578,130.92076 127.45317,130.616637 L147.312826,121.45895 C148.176937,121.05344 148.732834,120.179628 148.732834,119.223843 L148.732834,119.223188 Z M108.988806,101.057844 L123.929891,107.990062 L123.929891,124.524122 L108.988806,117.640224 L108.988806,101.057844 Z M126.386705,103.640464 L112.425626,97.2007203 L126.401535,90.7609765 L140.377443,97.2007203 L126.386705,103.640464 Z M72.0253761,48.6711109 L86.9417451,55.6033296 L86.9417451,72.1522192 L72.0253761,65.2924196 L72.0253761,48.6711109 Z M91.8850322,55.6033296 L106.826118,48.6711109 L106.826118,65.2916781 L91.8850322,72.1514777 L91.8850322,55.6033296 Z M89.4133886,38.4130485 L103.389297,44.8527923 L89.4133886,51.2925361 L75.4473666,44.8527923 L89.4133886,38.4130485 Z M49.9535989,90.7525729 L63.9295075,97.1923167 L49.9535989,103.641823 L35.9875781,97.2020797 L49.9535989,90.7525729 Z M52.4252425,107.928024 L67.3514981,101.044126 L67.3514981,117.641213 L52.4252425,124.525111 L52.4252425,107.928024 Z M32.5655863,101.058585 L47.4819553,107.990804 L47.4819553,124.524864 L32.5655863,117.640966 L32.5655863,101.058585 Z M89.62595,137.887308 L65.3296936,124.057229 L70.8764325,121.460026 C71.7501956,121.054515 72.310233,120.175883 72.310233,119.210459 L72.310233,97.2017089 C72.310233,96.9892959 72.2812653,96.7768952 72.2233424,96.5741463 L72.2233424,96.4245006 C72.165407,96.2507194 72.0930002,96.0865775 72.0012775,95.9272801 L72.0012775,95.8548609 C71.8902513,95.6810673 71.7550771,95.5265896 71.6054315,95.3865957 L71.4944052,95.2900533 L71.4944052,95.2852212 C71.3544113,95.1693629 71.1999336,95.0728082 71.0358041,94.9907496 L70.9730367,94.9907496 L56.0467812,88.1213106 L56.0467812,73.4508702 L67.1691773,66.9772649 L67.1691773,66.9724452 C67.1981449,67.9041436 67.7484687,68.7392996 68.588395,69.1351333 L88.3899799,78.3313776 C89.0416782,78.6306812 89.7947385,78.6306812 90.4513306,78.3313776 L110.320861,69.1736909 L110.325693,69.1736909 C111.189804,68.7730128 111.749731,67.9041312 111.75455,66.9482231 L122.664509,73.127332 L122.780367,86.9821301 L105.478862,94.952192 L105.416107,94.952192 C105.251977,95.0342505 105.102319,95.1356374 104.957506,95.2514956 L104.846479,95.348038 C104.696834,95.4880319 104.566492,95.6473417 104.455453,95.8163033 L104.455453,95.8935421 C104.358898,96.0480199 104.286491,96.2121494 104.228569,96.385943 L104.228569,96.5355886 C104.175465,96.7383376 104.146498,96.9507506 104.146498,97.1631513 L104.146498,119.225042 C104.127182,120.16156 104.643718,121.030454 105.478837,121.460149 L112.324178,124.612483 L89.62595,137.887308 Z M128.873178,124.525605 L128.873178,107.991545 L143.789547,101.059327 L143.789547,117.641583 L128.873178,124.525605 Z"
                    , Attributes.fill "#FFFFFF"
                    ]
                    []
                ]
            ]
    in
    encircle 176.4414062 toIcon


{-| -}
writing : Nri.Ui.Svg.V1.Svg
writing =
    let
        toIcon circle =
            [ Svg.g
                [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.g [ Attributes.transform "translate(16.500000, 17.877535)", Attributes.fill "#FFFFFF" ]
                    [ Svg.path [ Attributes.d "M2.08125,0.183695707 L6.031,0.190211268 C7.08814286,0.20193662 7.95103571,1.06700704 7.94839891,2.11577465 L7.94839891,2.11577465 L7.90214286,26.4536972 C7.90214286,26.839331 7.80303571,27.2171479 7.61803571,27.5532746 L7.61803571,27.5532746 L4.54703571,33.0120775 C4.43207143,33.2114085 4.21932143,33.3390845 3.98807143,33.3455986 C3.75153571,33.3416901 3.53482143,33.2127113 3.42117857,33.0094718 L3.42117857,33.0094718 L0.367357143,27.536338 C0.183678571,27.2015141 0.0872142857,26.8223944 0.0898042575,26.440669 L0.0898042575,26.440669 L0.137428571,2.10014085 C0.137428571,1.04355634 1.00957143,0.182394366 2.08125,0.183695707 L2.08125,0.183695707 Z M2.38385714,2.24084507 C2.33760714,2.24084507 2.29003571,2.24605634 2.257,2.25257042 C1.92796429,2.32552817 1.69275,2.61605634 1.69671429,2.9521831 L1.71125,26.4849648 C1.71125,26.6295775 1.76146429,26.7728873 1.85,26.8862324 L1.88435714,26.9292254 L3.26525,29.4176056 L4.78092857,29.4176056 L6.26357143,26.7715845 C6.31775,26.6764789 6.34682143,26.5605282 6.34682143,26.4458803 L6.34682143,25.9729577 C5.65042857,26.1358099 4.93685714,26.2178873 4.22328571,26.2178873 L4.08717857,26.2165845 C3.96164286,26.2165845 3.84667857,26.2126761 3.76210714,26.2087676 L3.05778571,26.2074648 L3.05778571,2.91179577 C3.06042857,2.73330986 2.99039286,2.5665493 2.86221429,2.44017606 C2.73007143,2.30989437 2.56489286,2.24084507 2.38385714,2.24084507 Z" ] []
                    , Svg.path [ Attributes.d "M12.35615,31.837588 C11.57915,31.837588 10.9461857,31.2122359 10.9461857,30.4435739 C10.9461857,29.6788204 11.5765071,29.0534683 12.3521857,29.0534683 L20.8740786,29.0534683 C21.9140429,29.0534683 22.2840429,29.8038908 22.2840429,30.4461796 C22.2840429,31.0884683 21.9140429,31.837588 20.8740786,31.837588 L12.35615,31.837588 Z" ] []
                    , Svg.path [ Attributes.d "M12.35615,23.2128099 C11.5804714,23.2128099 10.9475071,22.5887606 10.9461857,21.8187958 C10.9461857,21.0540423 11.5765071,20.429993 12.3521857,20.429993 L35.5155071,20.429993 C36.5554714,20.429993 36.9254714,21.1791127 36.9254714,21.8214014 C36.9254714,22.4636901 36.5554714,23.2128099 35.5155071,23.2128099 L12.35615,23.2128099 Z" ] []
                    , Svg.path [ Attributes.d "M12.35615,14.2444789 C11.5804714,14.2444789 10.9475071,13.6204296 10.9461857,12.8504648 C10.9461857,12.0857113 11.5765071,11.461662 12.3521857,11.461662 L35.5155071,11.461662 C36.5554714,11.461662 36.9254714,12.2107817 36.9254714,12.8530704 C36.9254714,13.4953592 36.5554714,14.2444789 35.5155071,14.2444789 L12.35615,14.2444789 Z" ] []
                    , Svg.path [ Attributes.d "M12.35615,5.62347887 C11.6227571,5.62347887 11.0188643,5.06717606 10.9527929,4.35974648 L10.9527929,4.23207042 C10.9527929,3.46471127 11.5831143,2.83935915 12.3587929,2.83935915 L35.5155071,2.83935915 C36.5554714,2.83935915 36.9254714,3.58978169 36.9254714,4.23207042 C36.9254714,4.87435915 36.5554714,5.62347887 35.5155071,5.62347887 L12.35615,5.62347887 Z" ] []
                    ]
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
passageQuizCircled : Nri.Ui.Svg.V1.Svg
passageQuizCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M45.5,20.1885 L45.5,47.1885 C45.5,48.8135 46.875,50.1885 48.5,50.1885 L22.375,50.1885 C20.75,50.1885 19.375,48.8135 19.375,47.1885 L19.375,20.1885 L45.5,20.1885 Z M41.375,24.4385 L32.875,24.4385 L32.875,30.4385 L41.375,30.4385 L41.375,24.4385 Z M29.5,24.4385 L23.625,24.4385 C23.125,24.4385 22.75,24.8135 22.75,25.3135 C22.75,25.8135 23.125,26.1885 23.625,26.1885 L29.5,26.1885 C30,26.1885 30.375,25.8135 30.375,25.3135 C30.375,24.8135 30,24.4385 29.5,24.4385 L29.5,24.4385 Z M50.625,30.4385 L50.625,47.1885 C50.625,48.4385 49.75,49.3135 48.5,49.3135 C47.375,49.3135 46.375,48.3135 46.375,47.1885 L46.375,30.4385 L50.625,30.4385 Z M29.5,28.8135 L23.625,28.8135 C23.125,28.8135 22.75,29.1885 22.75,29.5635 C22.75,30.0635 23.125,30.4385 23.625,30.4385 L29.5,30.4385 C30,30.4385 30.375,30.0635 30.375,29.5635 C30.375,29.1885 30,28.8135 29.5,28.8135 L29.5,28.8135 Z M41.375,33.9385 L23.625,33.9385 C23.125,33.9385 22.75,34.3135 22.75,34.8135 C22.75,35.3135 23.125,35.6885 23.625,35.6885 L41.375,35.6885 C41.875,35.6885 42.25,35.3135 42.25,34.8135 C42.125,34.3135 41.75,33.9385 41.375,33.9385 L41.375,33.9385 Z M41.375,38.5635 L23.625,38.5635 C23.125,38.5635 22.75,38.9385 22.75,39.4385 C22.75,39.9385 23.125,40.3135 23.625,40.3135 L41.375,40.3135 C41.875,40.3135 42.25,39.9385 42.25,39.4385 C42.125,38.9385 41.75,38.5635 41.375,38.5635 L41.375,38.5635 Z M41.375,43.3135 L23.625,43.3135 C23.125,43.3135 22.75,43.6885 22.75,44.1885 C22.75,44.6885 23.125,45.0635 23.625,45.0635 L41.375,45.0635 C41.875,45.0635 42.25,44.6885 42.25,44.1885 C42.125,43.6885 41.75,43.3135 41.375,43.3135 L41.375,43.3135 Z", Attributes.fill "#FFFFFF", Attributes.fillRule "nonzero" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
planningDiagnosticCircled : Nri.Ui.Svg.V1.Svg
planningDiagnosticCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.g [ Attributes.transform "translate(15.000000, 14.811500)", Attributes.fill "#FFFFFF" ]
                    [ Svg.path [ Attributes.d "M7.65053084,20.1507422 C7.68983075,20.1540161 7.72749159,20.1622031 7.76515662,20.1736682 C7.80281746,20.1851291 7.83884342,20.1982291 7.87323032,20.2178811 C7.90598234,20.234255 7.93381715,20.2555419 7.96329104,20.2784679 C7.99604306,20.3046679 8.02551694,20.3325069 8.05171688,20.3652547 C8.06317778,20.3799896 8.07955588,20.3881765 8.09101678,20.4029155 C8.10247769,20.4192895 8.10411675,20.4373024 8.11230371,20.4553154 C8.13195576,20.4913414 8.14669061,20.5273674 8.1581557,20.5666631 C8.1696166,20.605963 8.17780775,20.6436238 8.18271657,20.6845628 C8.18271657,20.7025758 8.19254259,20.7189497 8.19254259,20.7386017 C8.19254259,20.7582538 8.18271657,20.7746277 8.18108169,20.7926407 C8.17780775,20.8335797 8.1696166,20.8728796 8.15651663,20.9121795 C8.14505573,20.9482054 8.13195576,20.9825923 8.11558185,21.0153402 C8.09756887,21.0480922 8.07791682,21.0775661 8.05335594,21.1070399 C8.02715601,21.139792 7.999317,21.1676268 7.96820405,21.1938267 C7.95346501,21.2052876 7.94527805,21.2216657 7.92890414,21.2331266 C6.96768079,21.8848553 6.3945519,22.9623226 6.3945519,24.1183896 C6.3945519,26.0407944 7.95837383,27.6062512 9.88241348,27.6062512 C11.8048183,27.6062512 13.3702751,26.0424293 13.3702751,24.1183896 C13.3702751,22.9623226 12.7971462,21.8832205 11.8359228,21.2331266 C11.8195489,21.2216657 11.8113578,21.2052876 11.7966229,21.1938267 C11.7638709,21.1676268 11.7376751,21.1397878 11.7114752,21.1070399 C11.6869101,21.0775661 11.6672623,21.0480922 11.6492493,21.0153402 C11.6312363,20.9825923 11.6181364,20.9482012 11.6083103,20.9121795 C11.5968494,20.8728796 11.5886625,20.8335797 11.5837495,20.7926407 C11.5804755,20.7746277 11.5706495,20.7582538 11.5706495,20.7386017 C11.5706495,20.7189497 11.5804755,20.7025758 11.5821104,20.6829279 C11.5853885,20.6419889 11.5935755,20.6043281 11.6066755,20.5650282 C11.6181364,20.5257283 11.6328754,20.4897023 11.6525274,20.4536764 C11.6623493,20.4373024 11.6639883,20.4176504 11.6738144,20.4012765 C11.6852753,20.3849026 11.7016492,20.3767156 11.7131143,20.3636156 C11.7393142,20.3308636 11.7687881,20.3030288 11.8015401,20.2768289 C11.831014,20.2539029 11.858853,20.234255 11.8916008,20.216242 C11.9259877,20.1982291 11.9620137,20.1851291 11.9996745,20.1720291 C12.0373354,20.160564 12.0750004,20.1523771 12.1143003,20.1491031 C12.1323133,20.1491031 12.1503221,20.1392771 12.1699741,20.1392771 L19.2867158,20.1392771 L19.2867158,14.4930855 C18.4909084,15.08424 17.5215107,15.4182578 16.5046177,15.4182578 C13.9206331,15.4182578 11.8196495,13.3157232 11.8196495,10.7332895 C11.8196495,8.14930489 13.9221841,6.04832133 16.5046177,6.04832133 C17.5231456,6.04832133 18.4909084,6.38400752 19.2867158,6.97349356 L19.2867158,0.975174826 L1.28588876,0.975174826 C0.645646096,0.975174826 0.123282201,1.49753872 0.123282201,2.13778138 L0.123282201,20.1386106 L7.59340659,20.1386106 C7.61305864,20.1386106 7.63107162,20.1484324 7.65071948,20.1500715 L7.65053084,20.1507422 Z" ] []
                    , Svg.path [ Attributes.d "M38.4863913,0.975531145 L20.4855663,0.975531145 L20.4855663,8.44398084 C20.4855663,8.46362869 20.4757403,8.4800068 20.4741054,8.49801978 C20.4708273,8.53895876 20.4626404,8.57825866 20.4495404,8.61755857 C20.4380795,8.65358454 20.4249795,8.68797143 20.4086056,8.72071926 C20.3905926,8.75346709 20.3709406,8.78294516 20.3463797,8.81241904 C20.3201798,8.84516687 20.2923408,8.87300588 20.261232,8.89920582 C20.246493,8.91066672 20.238306,8.92704482 20.2219321,8.93850572 C20.205554,8.94996662 20.1875452,8.95160569 20.1695322,8.95979265 C20.1335062,8.9794447 20.0991194,8.99417955 20.0598194,9.00564464 C20.0205195,9.01710554 19.9812196,9.02529669 19.9402807,9.03020551 C19.9222677,9.03511852 19.9058938,9.04494455 19.8862417,9.04494455 C19.8665897,9.04494455 19.8518548,9.03511852 19.8322028,9.03348364 C19.7912638,9.03020551 19.7519639,9.02201855 19.712664,9.00891858 C19.676638,8.99745768 19.6422511,8.98435771 19.6095033,8.9679838 C19.5767513,8.94997082 19.5472774,8.92868389 19.5161644,8.9057579 C19.4834124,8.87955796 19.4555776,8.85171895 19.4293777,8.820606 C19.4179126,8.80586696 19.4015387,8.79768001 19.3900778,8.78130609 C18.738349,7.82008275 17.6608818,7.24695385 16.5048148,7.24695385 C14.58241,7.24695385 13.0169532,8.81077578 13.0169532,10.7348154 C13.0169532,12.6572202 14.5807751,14.222677 16.5048148,14.222677 C17.6608818,14.222677 18.7399839,13.6495481 19.3900778,12.6883248 C19.4015387,12.6719467 19.4179126,12.6637597 19.4293777,12.6506597 C19.4555776,12.6179119 19.4850515,12.5900729 19.5161644,12.565512 C19.5456383,12.5409512 19.5751122,12.5212991 19.6078642,12.5032861 C19.640612,12.4852732 19.6750031,12.4721732 19.712664,12.4607123 C19.7519639,12.4492514 19.7896247,12.4410644 19.8305637,12.4361514 C19.8502116,12.4345123 19.8665855,12.4246905 19.8846026,12.4246905 C19.9042505,12.4246905 19.9206244,12.4345123 19.9402765,12.4361514 C19.9795764,12.4394254 20.0172372,12.4476123 20.0565371,12.4590774 C20.095837,12.4705383 20.131863,12.4852773 20.1678848,12.5049294 C20.1842587,12.5147512 20.2039065,12.5147512 20.2186456,12.5262163 C20.2350195,12.5376772 20.2432064,12.5540511 20.2563064,12.5655162 C20.2890584,12.5917162 20.3152584,12.6195552 20.3414583,12.652303 C20.3660192,12.6817769 20.3856712,12.7112508 20.4036842,12.7440028 C20.4216972,12.7767506 20.4347972,12.8111417 20.4446232,12.8471635 C20.4560841,12.8864634 20.464271,12.9257633 20.4691841,12.9667023 C20.4757319,12.9863501 20.485558,13.0027282 20.485558,13.0223761 L20.485558,20.1391178 L26.1317495,20.1391178 C25.5405951,19.3433104 25.2049424,18.3739127 25.2049424,17.3553848 C25.2049424,14.7714001 27.307477,12.6704166 29.8899106,12.6704166 C32.4738953,12.6704166 34.5748789,14.7729512 34.5748789,17.3553848 C34.5748789,18.3739127 34.2391927,19.3433104 33.6480717,20.1391178 L39.6493249,20.1391178 L39.6493249,2.1382928 C39.6493249,1.49805014 39.126961,0.975531145 38.4867183,0.975531145 L38.4863913,0.975531145 Z" ] []
                    , Svg.path [ Attributes.d "M1.28579024,40.5015956 L19.2866152,40.5015956 L19.2866152,33.0314704 C19.2866152,33.0118183 19.2964413,32.9954444 19.2980803,32.9774314 C19.3013543,32.9364925 19.3095412,32.8971926 19.3226412,32.8578927 C19.3341021,32.8218667 19.3472021,32.7874798 19.3635802,32.754732 C19.381589,32.7219799 19.401241,32.6925061 19.4258061,32.6630322 C19.452006,32.6302802 19.479845,32.6024453 19.5109538,32.5762454 C19.5256886,32.5647803 19.5338756,32.5484064 19.5486146,32.5369455 C19.5649885,32.5254804 19.5830015,32.5238455 19.6010145,32.5156586 C19.6370405,32.4960065 19.6730664,32.4812675 19.7123663,32.4698066 C19.7516662,32.4583415 19.7893271,32.4501545 19.8302661,32.4468806 C19.8499139,32.4419676 19.866292,32.4321416 19.8859399,32.4321416 C19.9055877,32.4321416 19.9203268,32.4419676 19.9399788,32.4436066 C19.9809136,32.4468806 20.0202177,32.4550675 20.0595176,32.4681675 C20.0955436,32.4796284 20.1299305,32.4910935 20.1626783,32.5091065 C20.1970652,32.5271153 20.2265391,32.5484064 20.2560172,32.5713324 C20.288765,32.5975323 20.316604,32.6253713 20.3428039,32.6564843 C20.3542648,32.6712191 20.3706387,32.6794061 20.3821038,32.6957842 C21.0338326,33.6570075 22.1112998,34.2301364 23.2673668,34.2301364 C25.1897716,34.2301364 26.7552284,32.6663145 26.7552284,30.7422749 C26.7552284,28.8198701 25.1914065,27.2544133 23.2673668,27.2544133 C22.1112998,27.2544133 21.0321977,27.8275422 20.3821038,28.7887655 C20.3706387,28.8051394 20.3542648,28.8133264 20.3428039,28.8280654 C20.316604,28.8591742 20.288765,28.8870132 20.2560172,28.9132131 C20.2249042,28.937774 20.1954303,28.9590651 20.1610434,28.9770739 C20.1282914,28.9934478 20.0955436,29.0065478 20.0595176,29.0180087 C20.0185786,29.0311087 19.9792787,29.0392956 19.9367049,29.0425738 C19.920331,29.0442086 19.9039529,29.0540347 19.8859441,29.0540347 C19.866292,29.0540347 19.8499181,29.0442086 19.8319051,29.0425738 C19.7909662,29.0392956 19.7533053,29.0311087 19.7123663,29.0180087 C19.6730664,29.0065478 19.6370405,28.9918088 19.6026536,28.9721567 C19.5862797,28.9623307 19.5666276,28.9606958 19.5502537,28.9508698 C19.5338798,28.9394089 19.5256886,28.9230308 19.5109538,28.9115699 C19.4782018,28.8853699 19.452006,28.8575309 19.4258061,28.8247831 C19.401241,28.7953092 19.3815932,28.7658353 19.3635802,28.7330833 C19.3455672,28.7003355 19.3324672,28.6659444 19.3226412,28.6299226 C19.3111803,28.5906227 19.3029933,28.5513228 19.2980803,28.5103838 C19.2964413,28.490736 19.2866152,28.4743579 19.2866152,28.45471 L19.2866152,21.3379683 L13.6404279,21.3379683 C14.2315823,22.1337757 14.567235,23.1031734 14.567235,24.1217013 C14.567235,26.705686 12.4646962,28.8066695 9.88226676,28.8066695 C7.2982821,28.8066695 5.19729854,26.7041349 5.19729854,24.1217013 C5.19729854,23.1031734 5.53298473,22.1337757 6.12410565,21.3379683 L0.122850845,21.3379683 L0.122850845,39.338795 C0.122850845,39.9790376 0.64521474,40.5014015 1.2854574,40.5014015 L1.28579024,40.5015956 Z" ] []
                    , Svg.path [ Attributes.d "M32.1770269,21.3379138 C32.1049792,21.3379138 32.0362012,21.3215399 31.9690665,21.29534 C31.9559665,21.2904269 31.9428666,21.287153 31.9297666,21.2806009 C31.8691798,21.2527661 31.8151408,21.2167401 31.7660191,21.1692533 C31.756193,21.1594314 31.7480061,21.1479663 31.7381801,21.1381445 C31.7185322,21.1168534 31.6972453,21.0972055 31.6808672,21.0726447 C31.6694063,21.0562666 31.6677672,21.0382536 31.6595802,21.0202448 C31.6399324,20.9842188 31.6251934,20.9481929 31.6137283,20.9088971 C31.6022674,20.8695972 31.5940804,20.8319364 31.5891674,20.7909974 C31.5891674,20.7746193 31.5793414,20.7582454 31.5793414,20.7385975 C31.5793414,20.7189455 31.5891674,20.7025716 31.5908065,20.6845586 C31.5940804,20.6436196 31.6022674,20.6043197 31.6153673,20.5650198 C31.6268282,20.5289938 31.6399282,20.494607 31.6563063,20.4618591 C31.6743151,20.4291071 31.6939671,20.3996332 31.7185322,20.3701593 C31.7447321,20.3374073 31.7725712,20.3095725 31.8036841,20.2833726 C31.8184189,20.2719075 31.8266059,20.2555336 31.8413449,20.2440727 C32.8025683,19.5923439 33.3756972,18.5148767 33.3756972,17.3588097 C33.3756972,15.4364049 31.8118753,13.8709481 29.8878356,13.8709481 C27.9654308,13.8709481 26.399974,15.43477 26.399974,17.3588097 C26.399974,18.5148767 26.9731029,19.5939746 27.9343263,20.2440727 C27.9507002,20.2555336 27.9588871,20.2719075 27.9719871,20.2833726 C28.0047391,20.3095725 28.0309391,20.3374115 28.057139,20.3701593 C28.0816999,20.3996332 28.1013519,20.4291071 28.1193649,20.4618591 C28.1373779,20.4946111 28.1504779,20.528998 28.1603039,20.5650198 C28.1717648,20.6043197 28.1799517,20.6436196 28.1848647,20.6845586 C28.1914168,20.7025674 28.2012387,20.7189455 28.2012387,20.7385975 C28.2012387,20.7582454 28.1914168,20.7746193 28.1897778,20.7942714 C28.1865038,20.8352062 28.1783169,20.8728712 28.1652169,20.9121711 C28.1537518,20.951471 28.139017,20.987497 28.1193649,21.0235229 C28.1095389,21.0398968 28.1078998,21.0595447 28.098078,21.0759228 C28.0866129,21.0922967 28.070239,21.1004837 28.0587781,21.1135836 C28.0325781,21.1463315 28.0031042,21.1741705 27.9703522,21.2003704 C27.9408742,21.2232964 27.9114045,21.2445833 27.8786524,21.2625963 C27.8459004,21.2806093 27.8115135,21.2937093 27.7738527,21.3051702 C27.7345528,21.3166311 27.6968919,21.324818 27.655953,21.329731 C27.63794,21.3280962 27.6215619,21.337918 27.601914,21.337918 L20.4851723,21.337918 L20.4851723,26.9841096 C21.2809797,26.3929551 22.2503774,26.0589373 23.2672704,26.0589373 C25.8512551,26.0589373 27.9522386,28.1614719 27.9522386,30.7439055 C27.9522386,33.3278902 25.849704,35.4288738 23.2672704,35.4288738 C22.2487426,35.4288738 21.2809797,35.0931876 20.4851723,34.5037015 L20.4851723,40.5020215 L38.4859973,40.5020215 C39.12624,40.5020215 39.6486039,39.9796576 39.6486039,39.339415 L39.6486039,21.3385887 L32.1784774,21.3385887 L32.1768383,21.3385887 L32.1770269,21.3379138 Z" ] []
                    ]
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
quizCircled : Nri.Ui.Svg.V1.Svg
quizCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M27.7066041,24.1406748 C26.993092,24.1406748 26.4038432,23.5928472 26.3383711,22.8940328 L26.3397072,22.7684333 C26.3397072,22.0108277 26.9543432,21.3948556 27.7092764,21.3948556 L50.2744322,21.3948556 C51.2872454,21.3948556 51.6466738,22.1350911 51.6466738,22.7684333 C51.6466738,23.4004394 51.2872454,24.1406748 50.2744322,24.1406748 L27.7066041,24.1406748 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M20.3149812,24.9539297 C20.1485622,24.9539297 19.9879711,24.8898228 19.8675278,24.7742361 L18.0479274,23.0339599 C17.7892333,22.7869216 17.7801676,22.3770258 18.0275297,22.1186555 C18.2739204,21.8602852 18.68414,21.8508958 18.9428341,22.0982579 L20.2861654,23.3826627 L23.7243037,19.6583096 C23.9671329,19.3950828 24.3767049,19.3788941 24.6392843,19.6213996 C24.9021874,19.8642288 24.9186998,20.2738008 24.6761943,20.5363802 L20.7909265,24.7454204 C20.6727496,24.8733104 20.5089208,24.9481018 20.335055,24.953606 C20.3285796,24.9539297 20.3217804,24.9539297 20.3149812,24.9539297", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M20.3149812,32.9539297 C20.1485622,32.9539297 19.9879711,32.8898228 19.8675278,32.7742361 L18.0479274,31.0339599 C17.7892333,30.7869216 17.7801676,30.3770258 18.0275297,30.1186555 C18.2739204,29.8602852 18.68414,29.8508958 18.9428341,30.0982579 L20.2861654,31.3826627 L23.7243037,27.6583096 C23.9671329,27.3950828 24.3767049,27.3788941 24.6392843,27.6213996 C24.9021874,27.8642288 24.9186998,28.2738008 24.6761943,28.5363802 L20.7909265,32.7454204 C20.6727496,32.8733104 20.5089208,32.9481018 20.335055,32.953606 C20.3285796,32.9539297 20.3217804,32.9539297 20.3149812,32.9539297", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M20.3149812,49.5652859 C20.1485622,49.5652859 19.9879711,49.501179 19.8675278,49.3855923 L18.0479274,47.6453161 C17.7892333,47.3982778 17.7801676,46.988382 18.0275297,46.7300117 C18.2739204,46.4716414 18.68414,46.462252 18.9428341,46.7096141 L20.2861654,47.9940189 L23.7243037,44.2696659 C23.9671329,44.006439 24.3767049,43.9902503 24.6392843,44.2327558 C24.9021874,44.4755851 24.9186998,44.885157 24.6761943,45.1477364 L20.7909265,49.3567766 C20.6727496,49.4846666 20.5089208,49.559458 20.335055,49.5649622 C20.3285796,49.5652859 20.3217804,49.5652859 20.3149812,49.5652859", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M18.8324383,37.3886648 C18.5195828,37.0758093 18.5195828,36.6127831 18.8324383,36.2999276 C19.1452938,35.9870721 19.60832,35.9870721 19.9211755,36.2999276 L21.3227682,37.7015203 L22.724361,36.2999276 C23.0372165,35.9870721 23.5565566,35.9870721 23.863155,36.2999276 C24.1760106,36.6127831 24.1760106,37.1321233 23.863155,37.4387217 L22.4615623,38.8403144 L23.863155,40.2419071 C24.1760106,40.5547626 24.1760106,41.0177888 23.863155,41.3306443 C23.5502995,41.6434998 23.0872734,41.6434998 22.7744178,41.3306443 L21.3728251,39.9290516 L19.9712324,41.3306443 C19.6583769,41.6434998 19.1390367,41.6434998 18.8324383,41.3306443 C18.5195828,41.0177888 18.5195828,40.4984486 18.8324383,40.1918502 L20.234031,38.8403144 L18.8324383,37.3886648 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M27.7066041,32.1644352 C26.993092,32.1644352 26.4038432,31.6179437 26.3383711,30.9191294 L26.3397072,30.7935298 C26.3397072,30.0359242 26.9543432,29.418616 27.7092764,29.418616 L50.2744322,29.418616 C51.2872454,29.418616 51.6466738,30.1588514 51.6466738,30.7935298 C51.6466738,31.4255359 51.2872454,32.1644352 50.2744322,32.1644352 L27.7066041,32.1644352 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M27.7066041,48.2119559 C26.9516708,48.2119559 26.3343626,47.5959838 26.3330264,46.8370421 C26.3330264,46.083445 26.9476623,45.4661367 27.7025956,45.4661367 L50.2744322,45.4661367 C51.2872454,45.4661367 51.6466738,46.2063721 51.6466738,46.8410506 C51.6466738,47.4730566 51.2872454,48.2119559 50.2744322,48.2119559 L27.7066041,48.2119559 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M27.7066041,40.1881956 C26.9516708,40.1881956 26.3343626,39.5708873 26.3330264,38.8132817 C26.3330264,38.0583484 26.9476623,37.4423763 27.7025956,37.4423763 L50.2744322,37.4423763 C51.2872454,37.4423763 51.6466738,38.1812756 51.6466738,38.815954 C51.6466738,39.4479601 51.2872454,40.1881956 50.2744322,40.1881956 L27.7066041,40.1881956 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
unitDiagnosticCircled : Nri.Ui.Svg.V1.Svg
unitDiagnosticCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M37.9626487,27.1000681 C37.8614933,27.1000681 37.7649285,27.077079 37.6706709,27.0402942 C37.6522785,27.0333963 37.633886,27.0287996 37.6154936,27.0196005 C37.5304293,26.9805202 37.4545583,26.9299395 37.385591,26.8632676 C37.3717952,26.8494777 37.3603007,26.8333807 37.3465049,26.8195907 C37.3189191,26.7896979 37.2890322,26.7621121 37.2660372,26.7276285 C37.249946,26.7046336 37.2476447,26.6793432 37.2361502,26.6540588 C37.2085645,26.6034781 37.1878708,26.5528974 37.1717737,26.4977259 C37.1556825,26.4425486 37.144188,26.3896725 37.1372901,26.332194 C37.1372901,26.309199 37.1234943,26.2862099 37.1234943,26.2586242 C37.1234943,26.2310326 37.1372901,26.2080435 37.1395914,26.1827532 C37.144188,26.1252746 37.1556825,26.0700972 37.174075,26.0149199 C37.1901662,25.9643392 37.2085586,25.9160598 37.2315536,25.8700816 C37.256838,25.8240976 37.2844296,25.7827161 37.3189191,25.7413345 C37.355704,25.6953505 37.3947902,25.6562702 37.438473,25.6194853 C37.4591608,25.6033883 37.4706553,25.5803992 37.491349,25.564308 C38.8409129,24.6492766 39.6455896,23.1365056 39.6455896,21.5133799 C39.6455896,18.8143111 37.4499734,16.6163995 34.7486092,16.6163995 C32.0495403,16.6163995 29.8516287,18.8120157 29.8516287,21.5133799 C29.8516287,23.1365056 30.6563054,24.6515661 32.0058693,25.564308 C32.0288584,25.5803992 32.0403529,25.6033883 32.0587453,25.6194853 C32.1047294,25.6562702 32.1415143,25.6953564 32.1782992,25.7413345 C32.2127828,25.7827161 32.2403744,25.8240976 32.2656647,25.8700816 C32.2909551,25.9160657 32.3093475,25.9643451 32.3231433,26.0149199 C32.3392345,26.0700972 32.3507291,26.1252746 32.357627,26.1827532 C32.3668261,26.2080376 32.380616,26.2310326 32.380616,26.2586242 C32.380616,26.2862099 32.3668261,26.309199 32.3645249,26.3367906 C32.3599282,26.3942633 32.3484337,26.4471452 32.3300412,26.5023226 C32.3139442,26.5574999 32.2932563,26.6080806 32.2656647,26.6586613 C32.2518689,26.6816504 32.2495677,26.7092361 32.2357778,26.732231 C32.2196807,26.7552201 32.1966916,26.7667147 32.1806004,26.7851071 C32.1438155,26.8310853 32.102434,26.8701714 32.05645,26.9069563 C32.0150626,26.9391446 31.9736869,26.9690315 31.9277029,26.9943219 C31.8817188,27.0196122 31.8334394,27.0380047 31.7805633,27.0540958 C31.725386,27.070187 31.6725099,27.0816816 31.6150314,27.0885795 C31.589741,27.0862841 31.566746,27.100074 31.5391603,27.100074 L21.5472085,27.100074 L21.5472085,35.0273638 C22.6645273,34.1973791 24.025568,33.728416 25.4532924,33.728416 C29.0812237,33.728416 32.0310184,36.6803883 32.0310184,40.306142 C32.0310184,43.9340733 29.0790461,46.8838679 25.4532924,46.8838679 C24.0232726,46.8838679 22.6645273,46.4125623 21.5472085,45.5849201 L21.5472085,54.0066005 L46.8204843,54.0066005 C47.7193892,54.0066005 48.4527915,53.2731982 48.4527915,52.3742933 L48.4527915,27.1010157 L37.9646852,27.1010157 L37.9623839,27.1010157 L37.9626487,27.1000681 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 71 toIcon


{-| -}
quickWriteCircled : Nri.Ui.Svg.V1.Svg
quickWriteCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.g [ Attributes.transform "translate(12.500000, 18.400000)", Attributes.fill "#FFFFFF" ]
                    [ Svg.path [ Attributes.d "M16.838,20.0521143 L14.338,22.5371143 L6.5,22.5379714 L6.5,20.0522571 L16.838,20.0521143 Z M21.339,15.5771143 L18.838,18.0631143 L2,18.0636857 L2,15.5779714 L21.339,15.5771143 Z M26.339,10.6061143 L23.838,13.0921143 L5.5,13.0922571 L5.5,10.6065429 L26.339,10.6061143 Z M31.338,5.63511429 L28.839,8.12011429 L1.0658141e-14,8.12082857 L1.0658141e-14,5.63511429 L31.338,5.63511429 Z" ] []
                    , Svg.path [ Attributes.d "M12.416,26.8879714 L17.62495,32.067156 L10.33395,34.1373086 L12.416,26.8879714 Z M34.625,4.85261143 L39.781,9.97914857 L19.158,30.4843029 L14.002,25.3577657 L34.625,4.85261143 Z M39.5785,3.62376795e-14 L44.7345,5.12653714 L41.27355,8.56771029 L36.11755,3.44117314 L39.5785,3.62376795e-14 Z" ] []
                    ]
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
guidedDraftCircled : Nri.Ui.Svg.V1.Svg
guidedDraftCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M56.6059844,47.0760445 L48.4447276,29.1927202 C48.310599,28.8809029 48.044072,28.7014662 47.6869763,28.7014662 L38.0991385,28.7014662 C37.4755276,29.9051635 36.9842736,30.8858878 36.8954412,31.0200283 C36.4947855,31.8230878 35.6917439,32.3125581 34.8433763,32.3125581 C33.9514844,32.3125581 33.1484249,31.821304 32.7913114,31.0200283 L31.5876141,28.7014662 L21.9997763,28.7014662 C21.6879649,28.7014662 21.3761655,28.8791489 21.2420249,29.1927202 L13.0807686,47.0760445 C12.946637,47.3443078 12.9919273,47.6108229 13.1260589,47.879104 C13.2601907,48.102077 13.5267147,48.2362056 13.794978,48.2362056 L55.848126,48.2362056 C56.1163893,48.2362056 56.3829044,48.102077 56.5170449,47.879104 C56.6947276,47.656131 56.7400179,47.3443256 56.6058833,47.0760445 L56.6059844,47.0760445 Z M23.9631931,37.7566662 C23.4719331,37.7566662 23.0713012,37.3560105 23.0713012,36.8647743 C23.0713012,36.3735202 23.4719568,35.9728824 23.9631931,35.9728824 L24.4979714,35.9728824 C24.9892255,35.9728824 25.3898633,36.3735381 25.3898633,36.8647743 C25.3898633,37.3560283 24.9892076,37.7566662 24.4979714,37.7566662 L23.9631931,37.7566662 Z M28.0655331,41.4583743 C27.9766947,41.6813472 27.7537217,41.8590299 27.5307547,41.8590299 C27.4854644,41.8590299 27.396626,41.8590299 27.353072,41.8137397 C27.3077817,41.8137397 27.0412547,41.679611 26.9959644,41.679611 C26.1493866,41.3225035 25.4351595,40.7877191 24.9003812,40.0299678 C24.9003812,39.9846716 24.7226985,39.8069948 24.6774082,39.7616986 C24.4997255,39.4934353 24.5432736,39.1380878 24.8115368,38.9586391 C25.0798001,38.7809564 25.4351476,38.8245105 25.6145963,39.0927737 C25.6598866,39.138064 25.7487309,39.3157467 25.792279,39.3157467 C26.2382249,39.8958332 26.8183114,40.296471 27.4419222,40.6082764 C27.4872125,40.6082764 27.6648952,40.6971148 27.7101855,40.6971148 C28.0202547,40.8329916 28.1997033,41.1448029 28.0655509,41.4583445 L28.0655331,41.4583743 Z M33.1051682,41.3242397 C33.0598779,41.3695299 32.7933568,41.4583743 32.7933568,41.5019224 C32.169746,41.8137397 31.455519,41.9931764 30.6524595,42.0820089 C30.5183249,42.0820089 30.3841963,42.1272991 30.2518039,42.1272991 C30.2065136,42.1272991 29.8946963,42.1725953 29.8946963,42.1725953 C29.5828849,42.1725953 29.3146098,41.9496224 29.3146098,41.637817 C29.3146098,41.3259997 29.5375828,41.0577305 29.8493882,41.0577305 C29.8946785,41.0577305 30.3841666,41.0124343 30.472999,41.0124343 C31.1419179,40.9235959 31.7220044,40.7894613 32.2567828,40.5211802 C32.2567828,40.5211802 32.4797558,40.4323418 32.525046,40.3870516 C32.7933093,40.252917 33.1486568,40.3417613 33.2827974,40.6100245 C33.5057703,40.8329975 33.3716417,41.190111 33.1051147,41.3242516 L33.1051682,41.3242397 Z M36.7615682,37.0424451 C36.7162779,37.0877353 36.6274395,37.2654181 36.5838855,37.3107083 C36.4497568,37.5336813 36.2720741,37.8019683 36.1379395,38.0684656 C35.8696763,38.5144116 35.6031612,38.9603575 35.2913558,39.4063035 C35.2913558,39.4515878 35.1136731,39.6292764 35.0683828,39.6745608 C34.9342541,39.8086953 34.8001195,39.8975337 34.6224368,39.8975337 C34.4883082,39.8975337 34.3994639,39.8522494 34.2653352,39.7634051 C33.997072,39.5857224 33.9535179,39.2286267 34.1764909,38.9603456 C34.2217812,38.9150553 34.3541736,38.7373726 34.3541736,38.7373726 C34.6224368,38.336717 34.888952,37.8907889 35.1572331,37.4883672 C35.2913676,37.220104 35.4690503,36.9535889 35.6484871,36.7306159 C35.6484871,36.6853256 35.7826217,36.5076429 35.8261698,36.4623526 C36.0038525,36.1940894 36.3609482,36.1505413 36.6292293,36.3282181 C36.8504601,36.4187986 36.9392985,36.7759062 36.7616217,37.0424451 L36.7615682,37.0424451 Z M40.9092222,34.9921224 L40.5974109,34.9921224 C40.2855936,34.9921224 39.9738001,35.0374126 39.6602109,35.0809608 C39.2142649,35.126251 38.8571514,35.2586494 38.5000379,35.4380683 C38.5000379,35.4380683 38.2770649,35.5269067 38.2770649,35.572197 C38.1882206,35.6174932 38.0993822,35.6610413 38.0088017,35.6610413 C37.831119,35.6610413 37.608146,35.572197 37.5175476,35.3927781 C37.3398649,35.1245148 37.4722574,34.7691672 37.7405206,34.6350267 C37.7858109,34.5897364 38.052332,34.457344 38.052332,34.457344 C38.4982779,34.234371 38.989532,34.1002364 39.5678347,34.0113981 C39.9249422,33.9661078 40.2820617,33.9225537 40.6373914,33.9225537 L40.994499,33.9225537 C41.3063103,33.9225537 41.5745855,34.1908229 41.5745855,34.5026462 C41.4874833,34.723871 41.2209622,34.9921581 40.9091449,34.9921581 L40.9092222,34.9921224 Z M43.0048114,35.3927781 C42.7365482,35.2586494 42.6041558,34.901524 42.7365482,34.6350267 C42.8706828,34.3667635 43.2278022,34.234371 43.4942995,34.3667635 C43.5395898,34.4120537 43.8061168,34.5008921 43.8061168,34.5444462 C44.9209817,35.168057 45.5010682,36.0164245 45.7240412,36.4623705 C45.7240412,36.5076608 45.8581698,36.7741818 45.8581698,36.7741818 C45.9470141,37.0859991 45.8128795,37.3977926 45.5010682,37.4884089 C45.455772,37.5336991 45.3669336,37.5336991 45.3233855,37.5336991 C45.1004125,37.5336991 44.8774395,37.3995705 44.7886071,37.1765975 C44.7886071,37.1765975 44.6997628,37.0424629 44.6997628,36.9989148 C44.5220801,36.6418072 44.1196763,36.0181905 43.2277844,35.5722445 C43.2277844,35.5269543 43.0483655,35.3928197 43.0048114,35.3928197 L43.0048114,35.3927781 Z M47.1959898,41.4130483 C47.0618612,41.547177 46.9277266,41.590731 46.7500439,41.590731 C46.6159152,41.590731 46.4817806,41.5454408 46.3493882,41.4565964 L45.6351612,40.7876775 L45.0550747,41.5019045 C44.9209401,41.6360391 44.7868114,41.7248775 44.6091287,41.7248775 C44.4749941,41.7248775 44.3408655,41.6795872 44.2520212,41.5907489 C44.0290482,41.3677759 43.9837639,41.0106624 44.1631828,40.7876894 L44.7867936,40.0299381 L44.1178747,39.4063272 C43.8949017,39.1833543 43.8496114,38.8262408 44.0725844,38.6032678 C44.2955574,38.3802948 44.6526709,38.3350045 44.8756439,38.5579775 L45.4992547,39.138064 L46.0793412,38.423837 C46.3023141,38.200864 46.6594276,38.1555737 46.8824006,38.3349926 C47.1053736,38.5579656 47.1506639,38.9150791 46.9712449,39.1380521 L46.3476341,39.8958035 L47.1053855,40.5647224 C47.418939,40.7894435 47.418939,41.1448089 47.195966,41.4130483 L47.1959898,41.4130483 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M34.2199439,30.3530716 C34.4882071,30.8443256 35.2006682,30.8443256 35.4236412,30.3530716 C35.4236412,30.3530716 38.2769817,24.7787472 38.9459006,23.4409094 C39.6148195,22.1483797 39.6148195,20.6310932 38.9459006,19.2932553 C37.7857276,17.0182175 35.0212195,16.0828013 32.7481439,17.2411905 C30.473106,18.4013635 29.5812141,21.254704 30.696079,23.4389472 C31.8109439,25.6268472 34.2200747,30.3528932 34.2200747,30.3528932 L34.2199439,30.3530716 Z M34.8435547,18.9377472 C36.1813925,18.9377472 37.2509493,20.007304 37.2509493,21.3451418 C37.2509493,22.6829797 36.1813925,23.7525364 34.8435547,23.7525364 C33.5057168,23.7525364 32.4361601,22.6829797 32.4361601,21.3451418 C32.4361601,20.0526121 33.5057168,18.9377472 34.8435547,18.9377472 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
selfReviewCircled : Nri.Ui.Svg.V1.Svg
selfReviewCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M50.8790625,26.2612172 C51.096875,26.2612172 51.3088437,26.3462172 51.4645,26.5018734 C51.6201563,26.6575297 51.7072813,26.8673734 51.708875,27.0873109 C51.708875,37.6166859 44.5938437,46.2388734 35.68425,46.7456859 L35.68425,56.0404359 L39.6271875,56.0404359 C40.0861875,56.0404359 40.4575313,56.4117797 40.4575313,56.8702484 C40.4575313,57.3287172 40.0861875,57.7005922 39.6271875,57.7005922 L29.9780937,57.7005922 C29.5190937,57.7005922 29.14775,57.3287172 29.14775,56.8702484 C29.14775,56.4117797 29.5190937,56.0404359 29.9780937,56.0404359 L34.024625,56.0404359 L34.024625,46.7456859 C25.1139688,46.2388734 18,37.6188109 18,27.0873109 C18.002125,26.8673734 18.08925,26.6575297 18.2449062,26.5018734 C18.4005625,26.3462172 18.612,26.2612172 18.8298125,26.2612172 L22.1958125,26.2612172 L22.1958125,27.9213734 L19.676625,27.9213734 C20.0437188,37.4674047 26.7114375,45.1184672 34.8544375,45.1184672 C42.9974375,45.1184672 49.6651562,37.4674047 50.03225,27.9213734 L47.3053437,27.9213734 L47.3053437,26.2612172 L50.8790625,26.2612172 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M34.8543844,36.8509422 C30.3159156,36.8509422 26.6242594,32.4410359 26.6242594,27.0185672 C26.6242594,21.5982234 30.3159156,17.1861922 34.8543844,17.1861922 C39.3928531,17.1861922 43.0845094,21.5982234 43.0845094,27.0185672 C43.0845094,32.4389109 39.3928531,36.8509422 34.8543844,36.8509422 Z M36.8943844,25.0577234 L36.8943844,25.0598484 C37.2179156,24.7341922 37.2179156,24.2093172 36.8943844,23.8852547 C36.5687281,23.5617234 36.0433219,23.5617234 35.7197906,23.8852547 L32.3830094,27.2220359 C32.0589469,27.5460984 32.0589469,28.0709734 32.3830094,28.3950359 C32.7086656,28.7206922 33.2335406,28.7206922 33.5576031,28.3950359 L36.8943844,25.0577234 Z M28.8714469,23.7088797 C28.5473844,24.0345359 28.5473844,24.5599422 28.8714469,24.8834734 C29.1949781,25.2075359 29.7219781,25.2075359 30.0460406,24.8834734 L33.3828219,21.5488172 C33.7063531,21.2231609 33.7063531,20.6977547 33.3828219,20.3742234 C33.0571656,20.0501609 32.5317594,20.0501609 32.2082281,20.3742234 L28.8714469,23.7088797 Z M29.4563531,26.6350047 L29.4563531,26.6371297 C29.1328219,26.9606609 29.1328219,27.4860672 29.4563531,27.8095984 C29.7804156,28.1352547 30.3074156,28.1352547 30.6309469,27.8095984 L36.3089469,22.1337234 C36.6330094,21.8101922 36.6330094,21.2826609 36.3089469,20.9591297 C35.9854156,20.6355984 35.4584156,20.6355984 35.1343531,20.9591297 L29.4563531,26.6350047 Z", Attributes.fill "#FFFFFF", Attributes.fillRule "nonzero" ] []
                , Svg.path [ Attributes.d "M34.8543844,40.7377797 C28.4958531,40.7377797 23.3225406,34.5827172 23.3225406,27.0187797 C23.3225406,19.4548422 28.4958531,13.2997797 34.8543844,13.2997797 C41.2129156,13.2997797 46.3862281,19.4548422 46.3862281,27.0187797 C46.3862281,34.5827172 41.2129156,40.7377797 34.8543844,40.7377797 Z M34.8543844,15.5262484 C29.4005719,15.5262484 24.9641031,20.6809672 24.9641031,27.0187797 C24.9641031,33.3560609 29.4005719,38.5113109 34.8543844,38.5113109 C40.3081969,38.5113109 44.7446656,33.3565922 44.7446656,27.0187797 C44.7446656,20.6809672 40.3081969,15.5262484 34.8543844,15.5262484 Z", Attributes.fill "#FFFFFF", Attributes.fillRule "nonzero" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
peerReviewCircled : Nri.Ui.Svg.V1.Svg
peerReviewCircled =
    let
        toIcon circle =
            [ Svg.g [ Attributes.fillRule "evenodd" ]
                [ circle
                , Svg.path [ Attributes.d "M29.5138064,31.3137599 L27.7363487,34.7995073 C27.156207,35.940726 27.5452386,37.3882243 28.7208466,37.9969598 C29.4571967,38.376934 30.2786747,38.3135333 30.9320267,37.9335591 L30.9767186,37.9035727 L30.9767186,47.0285457 L28.6625341,47.0285457 L28.6625341,39.6920682 L28.0606844,39.6920682 L28.0606844,47.0285457 L25.681377,47.0285457 L25.681377,38.4840295 C25.681377,38.4574707 25.6830787,38.4321962 25.6830787,38.4069216 L25.6830787,35.3564142 L24.6704906,37.3411053 C24.3712674,37.9284176 23.6727985,38.1713109 23.1109585,37.8800072 C22.5491186,37.5904208 22.3363004,36.8775939 22.6355228,36.2902853 L24.6206912,32.3962814 C24.6555928,32.3294603 24.6939002,32.2660573 24.7385922,32.2090812 C24.9165074,31.6885937 25.4085435,31.3137599 25.9874093,31.3137599 L29.5138064,31.3137599 Z M28.4080029,25.5657344 C29.7147067,25.5657344 30.7741154,26.6315507 30.7741154,27.9471038 C30.7741154,29.2622356 29.7147067,30.329773 28.4080029,30.329773 C27.101299,30.329773 26.0423161,29.2622356 26.0423161,27.9471038 C26.0423161,26.6315507 27.101299,25.5657344 28.4080029,25.5657344 Z", Attributes.fill "#FFFFFF", Attributes.opacity "0.5" ] []
                , Svg.path [ Attributes.d "M37.6208982,29.8041463 C38.2593548,29.8041463 38.8011879,30.2175298 38.9974126,30.7915633 C39.0455091,30.8553996 39.0889179,30.9239419 39.1272325,30.9976232 L41.3150017,35.2895811 C41.6461405,35.9372959 41.4116252,36.7238042 40.7914649,37.043383 C40.1713165,37.3629498 39.4013419,37.096929 39.0723197,36.4475051 L37.9567247,34.2623265 L37.9567247,37.5737156 C37.9567247,37.6174165 37.9550266,37.658963 37.9499204,37.7009429 L37.9499204,47.0285457 L35.3114049,47.0285457 L35.3114049,39.0396426 L34.6810322,39.0396426 L34.6810322,47.0285457 L32.0425119,47.0285457 L32.0425119,37.7095122 C32.0425119,37.6808075 32.0425119,37.6525361 32.0442147,37.6221224 L32.0442147,34.2606054 L30.9286221,36.4475051 C30.5979031,37.096929 29.8279261,37.3629498 29.2077741,37.043383 C28.5876222,36.7238042 28.3547989,35.9372959 28.6842409,35.2895811 L30.8720125,30.9976232 C30.9103199,30.9239419 30.9537347,30.8553996 31.0018312,30.7915633 C31.1980499,30.2175298 31.741587,29.8041463 32.3783396,29.8041463 L37.6208982,29.8041463 Z M35.0496,23.4675136 C36.4883718,23.4688866 37.6558047,24.6446969 37.6558047,26.0926369 C37.6558047,27.5418563 36.4870069,28.7181946 35.0470774,28.7181946 C33.6071515,28.7181946 32.4383538,27.5418563 32.4383538,26.0926369 C32.4383538,24.6446969 33.6057867,23.4688866 35.0445548,23.4675136 L35.0445548,23.4675136 Z", Attributes.fill "#FFFFFF" ] []
                , Svg.path [ Attributes.d "M44.0118381,31.3137599 C44.5906943,31.3137599 45.0827328,31.6885937 45.2606492,32.2090812 C45.3036395,32.2673451 45.3436521,32.3294603 45.3785466,32.3962814 L47.3637173,36.2902853 C47.6629393,36.8775939 47.4501284,37.5904208 46.888289,37.8800072 C46.3264496,38.1713109 45.627974,37.9284176 45.3270539,37.3411053 L44.3161663,35.3564142 L44.3161663,38.3619413 C44.3161663,38.4004959 44.3144562,38.4390504 44.3110601,38.4776037 L44.3110601,47.0285457 L41.9321724,47.0285457 L41.9321724,39.6920682 L41.3303203,39.6920682 L41.3303203,47.0285457 L39.0157089,47.0285457 L39.0157089,37.8984335 L39.0672135,37.9335591 C39.7205702,38.3135333 40.5420495,38.376934 41.2783972,37.9969598 C42.4557092,37.3882243 42.8430404,35.940726 42.2628927,34.7995073 L40.4854386,31.3137599 L44.0118381,31.3137599 Z M41.6776388,25.5657344 C42.9843523,25.5657344 44.0437549,26.6315507 44.0437549,27.9471038 C44.0437549,29.2622356 42.9843523,30.329773 41.6776388,30.329773 C40.3709373,30.329773 39.3115347,29.2622356 39.3115347,27.9471038 C39.3115347,26.6315507 40.3709373,25.5657344 41.6776388,25.5657344 Z", Attributes.fill "#FFFFFF", Attributes.opacity "0.5" ] []
                , Svg.path [ Attributes.d "M24.1233587,51.4491341 C24.5862627,51.4118264 24.9922078,51.7612443 25.0283722,52.2271348 C25.0654407,52.6948452 24.7191668,53.1043193 24.258071,53.1416269 L24.258071,53.1416269 L22.7093315,53.266289 C29.8481796,58.5348555 41.4677941,58.2036365 48.0216834,52.2489734 C48.5514915,51.7639741 49.0496558,51.8904561 49.3281215,52.1679886 C49.6029708,52.4409713 49.7313543,52.9751075 49.1463955,53.5128834 C42.012068,59.9944031 29.5416865,60.3829486 21.7618248,54.688529 L21.7618248,54.688529 L21.8685097,56.047073 C21.9182357,56.6722034 21.4842632,56.9297171 21.0973044,56.9615651 C20.7103455,56.9925032 20.2411127,56.8068749 20.1913867,56.1817445 L20.1913867,56.1817445 L19.9174416,52.7084944 C19.9165375,52.6993949 19.921058,52.6912054 19.9201539,52.682106 C19.9183457,52.6684569 19.9111128,52.6538978 19.9102087,52.6402487 C19.879469,52.2489734 20.0639073,51.7748934 20.6823181,51.7257566 L20.6823181,51.7257566 Z M51.0444829,20.9934529 C51.3139075,20.7159205 51.8437156,20.5857987 52.3762361,21.1763514 C58.7954131,28.3785455 59.1823719,40.9675986 53.540729,48.8222214 L53.540729,48.8222214 L54.8860439,48.7139382 C55.5062629,48.6638914 55.7612218,49.1024836 55.7919615,49.4928489 C55.8227012,49.8832142 55.639167,50.3582041 55.018948,50.407341 L55.018948,50.407341 L51.5797157,50.6839635 L51.5797157,50.6839635 L51.5534965,50.6812337 C51.5399348,50.6848734 51.5254691,50.6903331 51.5119074,50.691243 C51.1249486,50.7221811 50.6548117,50.5365528 50.6059898,49.9105125 L50.6059898,49.9105125 L50.3320446,46.4381723 C50.2949761,45.9713718 50.6412501,45.5609878 51.10325,45.5236802 C51.566154,45.4872825 51.9720992,45.8367003 52.0082635,46.3035008 L52.0082635,46.3035008 L52.1330306,47.879521 C57.356975,40.6727772 57.0242627,28.9317904 51.1240445,22.3119595 C50.6439624,21.7769133 50.7696336,21.2746251 51.0444829,20.9934529 Z M18.4887678,20.3158188 C18.8757267,20.2857907 19.3449595,20.470509 19.3946855,21.0956395 L19.3946855,21.0956395 L19.6686306,24.5697995 C19.704795,25.0356901 19.3594252,25.4451641 18.8965212,25.4824718 C18.4345213,25.5197794 18.0285761,25.1712715 17.9906035,24.704471 L17.9906035,24.704471 L17.8667405,23.1275408 C12.6427962,30.3342847 12.9755085,42.0761814 18.8757267,48.6941925 C19.3567129,49.2292386 19.2301376,49.7333467 18.9552883,50.012699 C18.6867678,50.2911414 18.1569597,50.4212631 17.6244392,49.8298006 C11.2043581,42.6285164 10.8173993,30.0394633 16.4599463,22.1848405 L16.4599463,22.1848405 L15.1137273,22.2931237 C14.4944123,22.3431705 14.2385494,21.9045783 14.2078097,21.514213 C14.1770699,21.1229377 14.3606041,20.6497677 14.9808232,20.5997209 L14.9808232,20.5997209 L18.4218637,20.3230984 C18.4290966,20.3221884 18.4372336,20.3258282 18.4462747,20.3258282 C18.4607404,20.3249182 18.4743021,20.3176387 18.4887678,20.3158188 Z M20.4723839,17.2571384 C27.627506,10.7956375 40.1358601,10.4070921 47.9401327,16.0851326 L47.9401327,16.0851326 L47.8325437,14.7311383 C47.7828177,14.1069179 48.2185984,13.8503141 48.6064614,13.8193761 C48.9952284,13.7875281 49.4662694,13.9731563 49.5150913,14.5964669 L49.5150913,14.5964669 L49.7908447,18.0597076 C49.7908447,18.0678971 49.7872283,18.0751767 49.7872283,18.0842761 C49.7908447,18.0988352 49.7962694,18.1124843 49.7971735,18.1270434 C49.8279132,18.5174087 49.644379,18.9887588 49.0223517,19.0388057 L49.0223517,19.0388057 L45.571366,19.3154282 C45.1075578,19.3518258 44.7007086,19.0033179 44.6636401,18.5383373 C44.6265716,18.0724468 44.9737496,17.6638827 45.4366537,17.6265751 L45.4366537,17.6265751 L47.0034753,17.501003 C39.8429286,12.2433558 28.1772045,12.5782146 21.5998084,18.5174087 C21.0690962,19.001498 20.5691236,18.8741061 20.2906579,18.5965737 C20.0140004,18.3263208 19.8847128,17.7940045 20.4723839,17.2571384 Z", Attributes.fill "#FFFFFF" ] []
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
gradingAssistantCircled : Nri.Ui.Svg.V1.Svg
gradingAssistantCircled =
    let
        toIcon circle =
            [ circle
            , Svg.path
                [ Attributes.d "M49.1972 21.7474C49.0028 21.5517 48.7139 21.4835 48.4505 21.5679L41.6733 23.8262L35.9479 19.5932V19.595C35.7262 19.4317 35.4301 19.4065 35.183 19.5304C34.9377 19.6543 34.7833 19.9056 34.7851 20.1785L34.865 27.2405L29.0163 31.3155C28.791 31.4734 28.6766 31.7445 28.7202 32.0138C28.7638 32.2812 28.9582 32.5038 29.2198 32.5846L36.0425 34.6921L38.1557 41.4435V41.4452C38.2392 41.7073 38.4627 41.8994 38.7371 41.9425C39.0096 41.9838 39.284 41.8707 39.4439 41.6463L43.5865 35.8839L50.7362 35.988C51.0124 35.9916 51.2667 35.839 51.3921 35.5949C51.5175 35.3507 51.4921 35.0581 51.3267 34.8391L47.0623 29.1664L49.3717 22.4812C49.4589 22.2245 49.3917 21.9395 49.1972 21.7474ZM34.8504 35.8807C34.7668 35.7981 34.6651 35.7371 34.5524 35.7029L32.3521 35.0208C32.0941 34.94 31.8106 35.0082 31.6199 35.1967L18.7484 47.9136C17.691 48.9583 17.6783 50.6709 18.7339 51.7139C19.7896 52.7568 21.523 52.7425 22.5804 51.6977L35.4899 38.9432V38.945C35.6807 38.7565 35.7498 38.48 35.6716 38.2251L35.0321 36.1751H35.0303C34.9957 36.0638 34.934 35.9632 34.8504 35.8807Z"
                , Attributes.fill "white"
                ]
                []
            ]
    in
    encircle 70 toIcon


{-| -}
dailyWritingCircled : Nri.Ui.Svg.V1.Svg
dailyWritingCircled =
    let
        toIcon circle =
            [ circle
            , Svg.g
                [ Attributes.clipPath "url(#clip0_220_902)"
                ]
                [ Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M55 24.4653V49.9254C54.6825 51.8809 53.218 53.4704 51.3117 54H19.7524C17.5926 53.3999 16 51.4394 16 49.1275V25.2632C16 22.4775 18.3123 20.2019 21.143 20.2019H26.4256V16.347C26.4256 15.6048 27.0401 15 27.7944 15C28.5486 15 29.1631 15.6048 29.1631 16.347V20.2019H41.901V16.347C41.901 15.6048 42.5156 15 43.2698 15C44.024 15 44.6386 15.6048 44.6386 16.347V20.2019H49.9212C52.4761 20.2019 54.6088 22.0557 55 24.4653ZM21.143 22.8929H26.4256V24.75C26.4256 25.4929 27.0401 26.097 27.7944 26.097C28.5486 26.097 29.1631 25.4929 29.1631 24.75V22.8929H41.8545V24.75C41.8545 25.4929 42.4684 26.097 43.2233 26.097C43.9775 26.097 44.5914 25.4929 44.5914 24.75V22.8929H49.8746C51.1962 22.8929 52.2801 23.9619 52.2801 25.2607V29.763H18.7375V25.2607C18.7375 23.9619 19.8207 22.8929 21.143 22.8929ZM49.9212 51.4953H21.143C19.8207 51.4953 18.7375 50.2718 18.7375 48.7855V29.763H52.3266V48.7855C52.3266 50.2718 51.2434 51.4953 49.9212 51.4953Z"
                    , Attributes.fill "white"
                    ]
                    []
                , Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M25.3275 28.8667L27.7735 28.8704C28.4281 28.8771 28.9625 29.37 28.9609 29.9675L28.9322 43.8335C28.9322 44.0532 28.8709 44.2685 28.7563 44.46L26.8545 47.57C26.7833 47.6836 26.6516 47.7563 26.5084 47.76C26.3619 47.7578 26.2277 47.6843 26.1573 47.5685L24.2662 44.4503C24.1524 44.2596 24.0927 44.0436 24.0943 43.8261L24.1238 29.9586C24.1238 29.3566 24.6639 28.866 25.3275 28.8667ZM25.5149 30.0387C25.4863 30.0387 25.4568 30.0417 25.4364 30.0454C25.2326 30.087 25.0869 30.2525 25.0894 30.444L25.0984 43.8513C25.0984 43.9337 25.1295 44.0154 25.1843 44.0799L25.2056 44.1044L26.0607 45.5221H26.9993L27.9175 44.0146C27.9511 43.9604 27.9691 43.8944 27.9691 43.8291V43.5596C27.5378 43.6524 27.0959 43.6992 26.654 43.6992L26.5697 43.6984C26.492 43.6984 26.4208 43.6962 26.3684 43.694L25.9323 43.6932V30.421C25.9339 30.3193 25.8905 30.2243 25.8111 30.1523C25.7293 30.0781 25.627 30.0387 25.5149 30.0387Z"
                    , Attributes.fill "white"
                    ]
                    []
                , Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M31.6905 46.9008C31.2094 46.9008 30.8174 46.5445 30.8174 46.1066C30.8174 45.6709 31.2077 45.3146 31.6881 45.3146H36.9654C37.6095 45.3146 37.8386 45.7422 37.8386 46.1081C37.8386 46.474 37.6095 46.9008 36.9654 46.9008H31.6905Z"
                    , Attributes.fill "white"
                    ]
                    []
                , Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M31.6905 41.987C31.2102 41.987 30.8182 41.6315 30.8174 41.1928C30.8174 40.7571 31.2077 40.4016 31.6881 40.4016H46.0325C46.6765 40.4016 46.9056 40.8284 46.9056 41.1943C46.9056 41.5602 46.6765 41.987 46.0325 41.987H31.6905Z"
                    , Attributes.fill "white"
                    ]
                    []
                , Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M31.6905 36.8775C31.2102 36.8775 30.8182 36.5219 30.8174 36.0833C30.8174 35.6476 31.2077 35.292 31.6881 35.292H46.0325C46.6765 35.292 46.9056 35.7188 46.9056 36.0848C46.9056 36.4507 46.6765 36.8775 46.0325 36.8775H31.6905Z"
                    , Attributes.fill "white"
                    ]
                    []
                , Svg.path
                    [ Attributes.fillRule "evenodd"
                    , Attributes.clipRule "evenodd"
                    , Attributes.d "M31.6903 31.966C31.2362 31.966 30.8622 31.6491 30.8213 31.246V31.1733C30.8213 30.7361 31.2116 30.3798 31.692 30.3798H46.0323C46.6763 30.3798 46.9054 30.8073 46.9054 31.1733C46.9054 31.5392 46.6763 31.966 46.0323 31.966H31.6903Z"
                    , Attributes.fill "white"
                    ]
                    []
                ]
            , Svg.defs []
                [ Svg.clipPath
                    [ Attributes.id "clip0_220_902"
                    ]
                    [ Svg.rect
                        [ Attributes.width "39"
                        , Attributes.height "39"
                        , Attributes.fill "white"
                        , Attributes.transform "translate(16 15)"
                        ]
                        []
                    ]
                ]
            ]
    in
    encircle 70 toIcon


{-| -}
novelsCircled : Nri.Ui.Svg.V1.Svg
novelsCircled =
    let
        toIcon circle =
            [ circle
            , Svg.path
                [ Attributes.fill "#FFF"
                , Attributes.transform "translate(10 9)"
                , Attributes.d "M3.21249 33.6C3.59687 34.1719 4.37029 34.325 4.94373 33.9438C7.13125 32.4813 9.70293 31.7 12.3345 31.7C14.9658 31.7 17.5377 32.4812 19.7253 33.9438C19.93 34.0813 20.1722 34.1563 20.4191 34.1563H20.5691C20.8191 34.1594 21.066 34.0875 21.2753 33.95C23.4613 32.4828 26.0333 31.7 28.6661 31.7C31.2989 31.7 33.8709 32.4828 36.0569 33.95C36.2632 34.0844 36.5038 34.1563 36.7507 34.1563C37.1194 34.1609 37.4695 34.0031 37.7101 33.725C37.9522 33.4469 38.0585 33.0766 38.0007 32.7125V32.5188V9.37518C38.0007 8.95954 37.7944 8.5705 37.4507 8.33766C34.9554 6.66578 32.0367 5.74078 29.0351 5.6689C26.0335 5.59702 23.0727 6.38138 20.5007 7.93138C17.9272 6.3923 14.9695 5.61574 11.9711 5.69386C8.9742 5.77042 6.06027 6.69854 3.56947 8.36886C3.21791 8.59698 3.00383 8.98762 3.00071 9.40638V32.5V32.7C2.95384 33.0156 3.0304 33.3375 3.21321 33.6L3.21249 33.6ZM35.5001 10.0752V30.7376C31.1517 28.647 26.0845 28.6626 21.7501 30.7814V10.075C23.8267 8.82807 26.2033 8.16871 28.6253 8.16871C31.0473 8.16871 33.4237 8.82807 35.5005 10.075L35.5001 10.0752ZM12.3753 8.2002C14.7956 8.1877 17.1721 8.83612 19.2505 10.0752V30.8C14.9161 28.6812 9.84889 28.6656 5.50049 30.7562V10.0938C7.57549 8.84385 9.95369 8.18449 12.3757 8.18761L12.3753 8.2002Z"
                ]
                []
            ]
    in
    encircle 60 toIcon
